import { __decorate, __metadata } from 'tslib';
import { DOCUMENT, CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { Directive, Inject, Input, HostBinding, NgModule } from '@angular/core';
import * as i1 from 'ng-devui/utils';
import { WithConfig } from 'ng-devui/utils';

class TextareaDirective {
    get hasGlowStyle() {
        return this.showGlowStyle;
    }
    get gray() {
        return this.styleType === 'gray';
    }
    constructor(doc, devConfigService, el, render) {
        this.doc = doc;
        this.devConfigService = devConfigService;
        this.el = el;
        this.render = render;
        this.maxLengthBlocker = false;
        this.maxLengthCounter = false;
        this.resize = 'none';
        this.styleType = 'default';
        this.showGlowStyle = true;
        this.rows = 3;
        this.fontSize = 12;
        this.document = this.doc;
        const root = getComputedStyle(this.document.querySelector(':root'));
        this.fontSize = parseInt(root.getPropertyValue('--devui-font-size-sm'), 10) || 12;
    }
    ngAfterViewInit() {
        this.setMaxLengthBlocker();
        this.setMaxLengthCounter();
    }
    ngOnDestroy() {
        if (this.checkMaxLength) {
            this.checkMaxLength();
        }
        if (this.getMaxLength) {
            this.getMaxLength();
        }
        if (this.resizeWatcher) {
            this.resizeWatcher.unobserve();
        }
    }
    setMaxLengthBlocker() {
        if (this.maxLengthBlocker) {
            this.checkMaxLength = this.render.listen(this.el.nativeElement, 'compositionupdate', () => {
                /**
                 * 通过失焦中断composition输入事件规避chrome textarea中文符号输入超出最大宽度问题，如浏览器修复该问题可移除此方法
                 * 复现步骤：
                 * 1. 输若干入内容
                 * 2. 回车换行
                 * 3. 粘贴内容至最大长度
                 * 4. 输入中文等触发composition事件输入法的符号
                 */
                const max = this.el.nativeElement.maxLength;
                const len = (this.el.nativeElement.textContent || this.el.nativeElement.value).length;
                if (max <= len) {
                    this.el.nativeElement.blur();
                    this.el.nativeElement.focus();
                }
            });
        }
    }
    setMaxLengthCounter() {
        const max = this.el.nativeElement.maxLength;
        if (this.maxLengthCounter && max) {
            this.counter = this.document.createElement('span');
            this.counter.className = 'devui-textarea-counter';
            this.counterInner = this.document.createElement('i');
            this.counterInner.textContent = `${this.el.nativeElement.value.length}/${max}`;
            this.counterInner.style.width = `${(String(max).length * 2 + 1) * this.fontSize}px`;
            this.counter.appendChild(this.counterInner);
            this.el.nativeElement.after(this.counter);
            this.checkMaxLength = this.render.listen(this.el.nativeElement, 'input', () => {
                this.counterInner.textContent = `${this.el.nativeElement.value.length}/${this.el.nativeElement.maxLength}`;
            });
            this.resizeWatcher = new ResizeObserver(() => {
                this.counter.style.left = `${this.el.nativeElement.offsetWidth - this.counterInner.offsetWidth}px`;
                this.counter.style.top = `${this.el.nativeElement.offsetHeight - this.counter.offsetHeight}px`;
            }).observe(this.el.nativeElement);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: TextareaDirective, deps: [{ token: DOCUMENT }, { token: i1.DevConfigService }, { token: i0.ElementRef }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.2.3", type: TextareaDirective, selector: "[dTextarea]", inputs: { maxLengthBlocker: "maxLengthBlocker", maxLengthCounter: "maxLengthCounter", resize: "resize", error: "error", styleType: "styleType", showGlowStyle: "showGlowStyle" }, host: { properties: { "style.resize": "this.resize", "class.error": "this.error", "class.devui-glow-style": "this.hasGlowStyle", "class.devui-gray-style": "this.gray", "attr.rows": "this.rows" } }, exportAs: ["dTextarea"], ngImport: i0 }); }
}
__decorate([
    WithConfig(),
    __metadata("design:type", Object)
], TextareaDirective.prototype, "styleType", void 0);
__decorate([
    WithConfig(),
    __metadata("design:type", Object)
], TextareaDirective.prototype, "showGlowStyle", void 0);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: TextareaDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[dTextarea]',
                    exportAs: 'dTextarea',
                }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }, { type: i1.DevConfigService }, { type: i0.ElementRef }, { type: i0.Renderer2 }], propDecorators: { maxLengthBlocker: [{
                type: Input
            }], maxLengthCounter: [{
                type: Input
            }], resize: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['style.resize']
            }], error: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['class.error']
            }], styleType: [{
                type: Input
            }], showGlowStyle: [{
                type: Input
            }], hasGlowStyle: [{
                type: HostBinding,
                args: ['class.devui-glow-style']
            }], gray: [{
                type: HostBinding,
                args: ['class.devui-gray-style']
            }], rows: [{
                type: HostBinding,
                args: ['attr.rows']
            }] } });

class TextareaModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: TextareaModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.2.3", ngImport: i0, type: TextareaModule, declarations: [TextareaDirective], imports: [CommonModule], exports: [TextareaDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: TextareaModule, imports: [CommonModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: TextareaModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                    ],
                    exports: [TextareaDirective],
                    declarations: [TextareaDirective],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { TextareaDirective, TextareaModule };
//# sourceMappingURL=ng-devui-textarea.mjs.map
