import * as i0 from '@angular/core';
import { EventEmitter, Directive, Input, Output, HostListener, Component, ViewChild, Injectable, Inject, forwardRef, HostBinding, NgModule } from '@angular/core';
import * as i1 from 'ng-devui/i18n';
import { from, of, merge, Observable } from 'rxjs';
import { catchError, toArray, mergeMap, concatMap, last, map, debounceTime } from 'rxjs/operators';
import * as i6 from '@angular/common';
import { DOCUMENT, CommonModule } from '@angular/common';
import { __decorate, __metadata } from 'tslib';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import * as i5 from 'ng-devui/toast';
import { ToastModule } from 'ng-devui/toast';
import * as i4 from 'ng-devui/utils';
import { WithConfig } from 'ng-devui/utils';
import * as i7 from 'ng-devui/button';
import { ButtonModule } from 'ng-devui/button';
import * as i8 from 'ng-devui/progress';
import { ProgressModule } from 'ng-devui/progress';

class FileDropDirective {
    constructor(element) {
        this.enableDrop = false;
        this.isSingle = false;
        this.fileOver = new EventEmitter();
        this.fileDrop = new EventEmitter();
        this.element = element;
    }
    onDrop(event) {
        if (!this.enableDrop) {
            return;
        }
        const transfer = this._getTransfer(event);
        if (!transfer) {
            return;
        }
        this._preventAndStop(event);
        if (this.isSingle) {
            this.fileDrop.emit([transfer.files[0]]);
        }
        else {
            this.fileDrop.emit(transfer.files);
        }
    }
    onDragOver(event) {
        if (!this.enableDrop) {
            return;
        }
        const transfer = this._getTransfer(event);
        if (!this._haveFiles(transfer.types)) {
            return;
        }
        this._preventAndStop(event);
        this.fileOver.emit(true);
    }
    onDragLeave(event) {
        if (!this.enableDrop) {
            return;
        }
        if (this.element) {
            if (event.currentTarget === this.element[0]) {
                return;
            }
        }
        this._preventAndStop(event);
        this.fileOver.emit(false);
    }
    _getTransfer(event) {
        return event.dataTransfer ? event.dataTransfer : event.originalEvent.dataTransfer;
    }
    _preventAndStop(event) {
        event.preventDefault();
        event.stopPropagation();
    }
    _haveFiles(types) {
        if (!types) {
            return false;
        }
        if (types.indexOf) {
            return types.indexOf('Files') !== -1;
        }
        else if (types.contains) {
            return types.contains('Files');
        }
        else {
            return false;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: FileDropDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.2.3", type: FileDropDirective, selector: "[d-file-drop]", inputs: { enableDrop: "enableDrop", isSingle: "isSingle" }, outputs: { fileOver: "fileOver", fileDrop: "fileDrop" }, host: { listeners: { "drop": "onDrop($event)", "dragover": "onDragOver($event)", "dragleave": "onDragLeave($event)" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: FileDropDirective, decorators: [{
            type: Directive,
            args: [{
                    /* eslint-disable-next-line @angular-eslint/directive-selector*/
                    selector: '[d-file-drop]'
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { enableDrop: [{
                type: Input
            }], isSingle: [{
                type: Input
            }], fileOver: [{
                type: Output
            }], fileDrop: [{
                type: Output
            }], onDrop: [{
                type: HostListener,
                args: ['drop', ['$event']]
            }], onDragOver: [{
                type: HostListener,
                args: ['dragover', ['$event']]
            }], onDragLeave: [{
                type: HostListener,
                args: ['dragleave', ['$event']]
            }] } });

class IUploadOptions {
}
class IFileOptions {
}
var UploadStatus;
(function (UploadStatus) {
    UploadStatus[UploadStatus["preLoad"] = 0] = "preLoad";
    UploadStatus[UploadStatus["uploading"] = 1] = "uploading";
    UploadStatus[UploadStatus["uploaded"] = 2] = "uploaded";
    UploadStatus[UploadStatus["failed"] = 3] = "failed";
})(UploadStatus || (UploadStatus = {}));

class FileUploader {
    constructor(file, uploadOptions) {
        this.file = file;
        this.uploadOptions = uploadOptions;
        this.percentage = 0;
        this.file = file;
        this.uploadOptions = uploadOptions;
        this.status = UploadStatus.preLoad;
    }
    sendCommonHandle(uploadFiles) {
        const { uri, method, headers, authToken, authTokenHeader, additionalParameter, fileFieldName, withCredentials, responseType } = this.uploadOptions;
        const authTokenHeader_ = authTokenHeader || 'Authorization';
        const fileFieldName_ = fileFieldName || 'file';
        this.xhr = new XMLHttpRequest();
        this.xhr.open(method || 'POST', uri);
        if (withCredentials) {
            this.xhr.withCredentials = withCredentials;
        }
        if (responseType) {
            this.xhr.responseType = responseType;
        }
        if (authToken) {
            this.xhr.setRequestHeader(authTokenHeader_, authToken);
        }
        if (headers) {
            Object.keys(headers).forEach((key) => {
                this.xhr.setRequestHeader(key, headers[key]);
            });
        }
        this.xhr.upload.onprogress = (e) => {
            this.percentage = Math.round((e.loaded * 100) / e.total);
        };
        const formData = uploadFiles && uploadFiles.length
            ? this.oneTimeUploadFiles(fileFieldName_, additionalParameter, uploadFiles)
            : this.parallelUploadFiles(fileFieldName_, additionalParameter);
        this.xhr.send(formData);
        this.status = UploadStatus.uploading;
        this.xhr.onabort = () => {
            this.status = UploadStatus.preLoad;
            this.xhr = null;
        };
    }
    sendErrorAndLoadHandle(resolve, reject, isMultiple = false) {
        this.xhr.onerror = () => {
            this.response = this.xhr.response;
            this.status = UploadStatus.failed;
            if (isMultiple) {
                reject({ file: this.file, response: this.xhr.response, status: UploadStatus.failed });
            }
            else {
                reject({ file: this.file, response: this.xhr.response });
            }
        };
        this.xhr.onload = () => {
            if (this.xhr.readyState === 4 && this.xhr.status >= 200 && this.xhr.status < 300) {
                this.response = this.xhr.response;
                this.status = UploadStatus.uploaded;
                if (isMultiple) {
                    resolve({ file: this.file, response: this.xhr.response, status: UploadStatus.uploaded });
                }
                else {
                    resolve({ file: this.file, response: this.xhr.response });
                }
            }
            else {
                this.response = this.xhr.response;
                this.status = UploadStatus.failed;
                if (isMultiple) {
                    reject({ file: this.file, response: this.xhr.response, status: UploadStatus.failed });
                }
                else {
                    reject({ file: this.file, response: this.xhr.response });
                }
            }
        };
    }
    send(uploadFiles) {
        return new Promise((resolve, reject) => {
            this.sendCommonHandle(uploadFiles);
            this.sendErrorAndLoadHandle(resolve, reject);
        });
    }
    sendMultiple(uploadFiles) {
        return new Promise((resolve, reject) => {
            this.sendCommonHandle(uploadFiles);
            this.sendErrorAndLoadHandle(resolve, reject, true);
        });
    }
    parallelUploadFiles(fileFieldName_, additionalParameter) {
        const formData = new FormData();
        formData.append(fileFieldName_, this.file, this.file.name);
        if (additionalParameter) {
            Object.keys(additionalParameter).forEach((key) => {
                formData.append(key, additionalParameter[key]);
            });
        }
        return formData;
    }
    oneTimeUploadFiles(fileFieldName_, additionalParameter, uploadFiles) {
        const formData = new FormData();
        uploadFiles.forEach((element) => {
            formData.append(fileFieldName_, element.file, element.file.name);
            if (additionalParameter) {
                Object.keys(additionalParameter).forEach((key) => {
                    formData.append(key, additionalParameter[key]);
                });
            }
        });
        return formData;
    }
    cancel() {
        if (this.xhr) {
            this.xhr.abort();
        }
    }
}

class UploadComponent {
    constructor() {
        this.fileUploaders = [];
        this.filesWithSameName = [];
    }
    addFile(file, options) {
        if (options && options.checkSameName) {
            if (this.checkFileSame(file.name)) {
                this.fileUploaders.push(new FileUploader(file, options));
            }
        }
        else {
            this.fileUploaders.push(new FileUploader(file, options));
        }
    }
    checkFileSame(fileName) {
        let checkRel = true;
        for (let i = 0; i < this.fileUploaders.length; i++) {
            if (fileName === this.fileUploaders[i].file.name) {
                checkRel = false;
                if (this.filesWithSameName.indexOf(fileName) === -1) {
                    this.filesWithSameName.push(fileName);
                }
                break;
            }
        }
        return checkRel;
    }
    getFiles() {
        return this.fileUploaders.map((fileUploader) => {
            return fileUploader.file;
        });
    }
    getFullFiles() {
        return this.fileUploaders.map((fileUploader) => {
            return fileUploader;
        });
    }
    upload(oneFile, isMultipleUpload = false) {
        let uploads = [];
        if (oneFile) {
            oneFile.percentage = 0;
            uploads.push(from(oneFile.send()));
        }
        else {
            const preFiles = this.fileUploaders.filter((fileUploader) => fileUploader.status === UploadStatus.preLoad);
            const failedFiles = this.fileUploaders.filter((fileUploader) => fileUploader.status === UploadStatus.failed);
            const uploadFiles = preFiles.length > 0 ? preFiles : failedFiles;
            uploads = uploadFiles.map((fileUploader) => {
                fileUploader.percentage = 0;
                if (isMultipleUpload) {
                    return from(fileUploader.sendMultiple()).pipe(catchError((error) => of(error)));
                }
                else {
                    return from(fileUploader.send());
                }
            });
        }
        if (uploads.length > 0) {
            return merge(...uploads).pipe(toArray());
        }
        return from(Promise.reject('no files'));
    }
    oneTimeUpload() {
        const uploads = this.fileUploaders.filter((fileUploader) => fileUploader.status !== UploadStatus.uploaded);
        return from(this.dealOneTimeUploadFiles(uploads));
    }
    async dealOneTimeUploadFiles(uploads) {
        if (!uploads || !uploads.length) {
            return Promise.reject('no files');
        }
        // 触发文件上传
        let finalUploads = [];
        await uploads[0].send(uploads).finally(() => {
            finalUploads = uploads.map((file) => {
                file.status = uploads[0].status;
                file.percentage = uploads[0].percentage;
                return { file: file.file, response: uploads[0].response };
            });
        });
        return finalUploads;
    }
    deleteFile(file) {
        this.fileUploaders = this.fileUploaders.filter((fileUploader) => {
            return file !== fileUploader.file;
        });
    }
    removeFiles() {
        this.fileUploaders = [];
        this.filesWithSameName = [];
    }
    getSameNameFiles() {
        return this.filesWithSameName.join();
    }
    resetSameNameFiles() {
        this.filesWithSameName = [];
    }
}

class UploadedFilesComponent {
    constructor(i18n) {
        this.i18n = i18n;
        this.uploadedFiles = [];
        this.deleteUploadedFileEvent = new EventEmitter();
        // 解决templateContext 传递method.bind(this)引发模板中内嵌组件initialize问题
        this.deleteFileProxy = filePath => {
            this.deleteFile(filePath);
        };
    }
    ngOnInit() {
        this.i18nText = this.i18n.getI18nText().upload;
        this.i18nSubscription = this.i18n.langChange().subscribe((data) => {
            this.i18nText = data.upload;
        });
    }
    cleanUploadedFiles() {
        this.uploadedFiles = [];
    }
    addAndOverwriteFile(file) {
        this.cleanUploadedFiles();
        this.uploadedFiles.push(file);
    }
    addFile(file) {
        this.uploadedFiles.push(file);
    }
    deleteFile(filePath) {
        this.uploadedFiles = this.uploadedFiles.filter((file) => {
            return filePath !== file[this.filePath];
        });
        this.deleteUploadedFileEvent.emit(filePath);
    }
    ngOnDestroy() {
        if (this.i18nSubscription) {
            this.i18nSubscription.unsubscribe();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: UploadedFilesComponent, deps: [{ token: i1.I18nService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.2.3", type: UploadedFilesComponent, selector: "d-uploaded-files", inputs: { uploadedFiles: "uploadedFiles", uploadedFilesRef: "uploadedFilesRef", filePath: "filePath" }, outputs: { deleteUploadedFileEvent: "deleteUploadedFileEvent" }, exportAs: ["dUploadFiles"], ngImport: i0, template: "<ng-template\n  [ngTemplateOutlet]=\"uploadedFilesRef\"\n  [ngTemplateOutletContext]=\"{ $implicit: this, uploadedFiles: uploadedFiles, filePath: filePath, deleteFile: deleteFileProxy }\"\n>\n</ng-template>\n", dependencies: [{ kind: "directive", type: i6.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: UploadedFilesComponent, decorators: [{
            type: Component,
            args: [{ selector: 'd-uploaded-files', exportAs: 'dUploadFiles', preserveWhitespaces: false, template: "<ng-template\n  [ngTemplateOutlet]=\"uploadedFilesRef\"\n  [ngTemplateOutletContext]=\"{ $implicit: this, uploadedFiles: uploadedFiles, filePath: filePath, deleteFile: deleteFileProxy }\"\n>\n</ng-template>\n" }]
        }], ctorParameters: () => [{ type: i1.I18nService }], propDecorators: { uploadedFiles: [{
                type: Input
            }], uploadedFilesRef: [{
                type: Input
            }], filePath: [{
                type: Input
            }], deleteUploadedFileEvent: [{
                type: Output
            }] } });

class MultipleUploadViewComponent extends UploadComponent {
    constructor(i18n) {
        super();
        this.i18n = i18n;
        this.uploadedFiles = [];
        this.deleteUploadedFileEvent = new EventEmitter();
        this.UploadStatus = UploadStatus;
        this.fileUploaders = [];
        // 解决templateContext 传递method.bind(this)引发模板中内嵌组件initialize问题
        this.deleteFileProxy = file => {
            this.deleteFile(file);
        };
    }
    ngOnInit() {
        this.i18nText = this.i18n.getI18nText().upload;
        this.i18nSubscription = this.i18n.langChange().subscribe((data) => {
            this.i18nText = data.upload;
        });
    }
    addFile(file) {
        let uploadOptions = this.uploadOptions;
        if (this.setCustomUploadOptions) {
            uploadOptions = this.setCustomUploadOptions(file, this.uploadOptions);
        }
        super.addFile(file, uploadOptions);
    }
    deleteFile(file) {
        super.deleteFile(file);
        this.deleteUploadedFileEvent.emit(file);
    }
    deletePreUploadFile(file) {
        super.deleteFile(file);
    }
    removeFiles() {
        super.removeFiles();
    }
    _onDeleteUploadedFile(filePath) {
        this.deleteUploadedFileEvent.emit(filePath);
    }
    ngOnDestroy() {
        if (this.i18nSubscription) {
            this.i18nSubscription.unsubscribe();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: MultipleUploadViewComponent, deps: [{ token: i1.I18nService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.2.3", type: MultipleUploadViewComponent, selector: "d-multiple-upload-view", inputs: { uploadOptions: "uploadOptions", preloadFilesRef: "preloadFilesRef", uploadedFiles: "uploadedFiles", uploadedFilesRef: "uploadedFilesRef", filePath: "filePath", setCustomUploadOptions: "setCustomUploadOptions" }, outputs: { deleteUploadedFileEvent: "deleteUploadedFileEvent" }, viewQueries: [{ propertyName: "uploadedFilesComponent", first: true, predicate: ["dUploadedFiles"], descendants: true, static: true }], usesInheritance: true, ngImport: i0, template: "<d-uploaded-files\n  #dUploadedFiles\n  [uploadedFiles]=\"uploadedFiles\"\n  [filePath]=\"filePath\"\n  [uploadedFilesRef]=\"uploadedFilesRef\"\n  (deleteUploadedFileEvent)=\"_onDeleteUploadedFile($event)\"\n>\n</d-uploaded-files>\n<ng-template\n  [ngTemplateOutlet]=\"preloadFilesRef\"\n  [ngTemplateOutletContext]=\"{ $implicit: this, fileUploaders: fileUploaders, UploadStatus: UploadStatus, deleteFile: deleteFileProxy }\"\n>\n</ng-template>\n", dependencies: [{ kind: "directive", type: i6.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: UploadedFilesComponent, selector: "d-uploaded-files", inputs: ["uploadedFiles", "uploadedFilesRef", "filePath"], outputs: ["deleteUploadedFileEvent"], exportAs: ["dUploadFiles"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: MultipleUploadViewComponent, decorators: [{
            type: Component,
            args: [{ selector: 'd-multiple-upload-view', preserveWhitespaces: false, template: "<d-uploaded-files\n  #dUploadedFiles\n  [uploadedFiles]=\"uploadedFiles\"\n  [filePath]=\"filePath\"\n  [uploadedFilesRef]=\"uploadedFilesRef\"\n  (deleteUploadedFileEvent)=\"_onDeleteUploadedFile($event)\"\n>\n</d-uploaded-files>\n<ng-template\n  [ngTemplateOutlet]=\"preloadFilesRef\"\n  [ngTemplateOutletContext]=\"{ $implicit: this, fileUploaders: fileUploaders, UploadStatus: UploadStatus, deleteFile: deleteFileProxy }\"\n>\n</ng-template>\n" }]
        }], ctorParameters: () => [{ type: i1.I18nService }], propDecorators: { uploadedFilesComponent: [{
                type: ViewChild,
                args: ['dUploadedFiles', { static: true }]
            }], uploadOptions: [{
                type: Input
            }], preloadFilesRef: [{
                type: Input
            }], uploadedFiles: [{
                type: Input
            }], uploadedFilesRef: [{
                type: Input
            }], filePath: [{
                type: Input
            }], deleteUploadedFileEvent: [{
                type: Output
            }], setCustomUploadOptions: [{
                type: Input
            }] } });

class SelectFiles {
    constructor(i18n, doc) {
        this.i18n = i18n;
        this.doc = doc;
        this.selectFiles = ({ multiple, accept, webkitdirectory }) => {
            return new Promise((resolve) => {
                const tempNode = this.document.getElementById('d-upload-temp');
                if (tempNode) {
                    this.document.body.removeChild(tempNode);
                }
                const input = this.document.createElement('input');
                input.style.position = 'fixed';
                input.style.left = '-2000px';
                input.style.top = '-2000px';
                input.setAttribute('id', 'd-upload-temp');
                input.setAttribute('type', 'file');
                if (multiple) {
                    input.setAttribute('multiple', '');
                }
                if (accept) {
                    input.setAttribute('accept', accept);
                }
                if (webkitdirectory) {
                    input.setAttribute('webkitdirectory', '');
                }
                input.addEventListener('change', event => {
                    resolve(Array.prototype.slice.call(event.target.files));
                });
                this.document.body.appendChild(input); // Fix compatibility issue with Internet Explorer 11
                this.simulateClickEvent(input);
            });
        };
        this.isAllowedFileType = (accept, file) => {
            if (accept) {
                const acceptArr = accept.split(',');
                const baseMimeType = file.type.replace(/\/.*$/, '');
                return acceptArr.some((type) => {
                    const validType = type.trim();
                    //  suffix name (e.g. '.png,.xlsx')
                    if (validType.startsWith('.')) {
                        return (file.name.toLowerCase().indexOf(validType.toLowerCase(), file.name.toLowerCase().length - validType.toLowerCase().length) > -1);
                        // mime type like 'image/*'
                    }
                    else if (/\/\*$/.test(validType)) {
                        return baseMimeType === validType.replace(/\/.*$/, '');
                    }
                    //  mime type like 'text/plain,application/json'
                    return file.type === validType;
                });
            }
            return true;
        };
        this.beyondMaximalSize = (fileSize, maximumSize) => {
            if (maximumSize) {
                return fileSize > 1024 * 1024 * maximumSize;
            }
            return false;
        };
        this.beyondAllFilesMaximalSize = (fileSize, maximumSize) => {
            if (maximumSize) {
                return fileSize > 1024 * 1024 * maximumSize;
            }
            return false;
        };
        this.beyondMaximumFileCount = (files, maximumCount) => {
            if (maximumCount) {
                return files > maximumCount;
            }
            return false;
        };
        this.triggerSelectFiles = (fileOptions, uploadOptions) => {
            const { multiple, accept, webkitdirectory } = fileOptions;
            return from(this.selectFiles({ multiple, accept, webkitdirectory })).pipe(mergeMap(file => file));
        };
        this.triggerDropFiles = (fileOptions, uploadOptions, files) => {
            return new Observable(observer => observer.next(files)).pipe(mergeMap(file => file));
        };
        this.document = this.doc;
        this.i18nText = this.i18n.getI18nText().upload;
        this.i18nSubscription = this.i18n.langChange().subscribe((data) => {
            this.i18nText = data.upload;
        });
    }
    checkAllFilesSize(fileSize, maximumSize) {
        if (this.beyondMaximalSize(fileSize, maximumSize)) {
            this.BEYOND_MAXIMAL_FILE_SIZE_MSG = this.i18nText.getAllFilesBeyondMaximalFileSizeMsg(maximumSize);
            return { checkError: true, errorMsg: this.BEYOND_MAXIMAL_FILE_SIZE_MSG };
        }
    }
    _validateFiles(filesLen, currentFile, accept, uploadOptions) {
        if (!this.isAllowedFileType(accept, currentFile)) {
            this.NOT_ALLOWED_FILE_TYPE_MSG = this.i18nText.getNotAllowedFileTypeMsg(currentFile.name, accept);
            return { checkError: true, errorMsg: this.NOT_ALLOWED_FILE_TYPE_MSG };
        }
        if (this.beyondMaximalSize(currentFile.size, uploadOptions.maximumSize)) {
            this.BEYOND_MAXIMAL_FILE_SIZE_MSG = this.i18nText.getBeyondMaximalFileSizeMsg(currentFile.name, uploadOptions.maximumSize);
            return { checkError: true, errorMsg: this.BEYOND_MAXIMAL_FILE_SIZE_MSG };
        }
        if (this.beyondMaximumFileCount(filesLen, uploadOptions.maximumCount)) {
            this.BEYOND_MAXIMAL_FILE_COUNT_MSG = this.i18nText.getBeyondMaximumFileCountMsg(uploadOptions.maximumCount);
            return { checkError: true, errorMsg: this.BEYOND_MAXIMAL_FILE_COUNT_MSG };
        }
        return { checkError: false, errorMsg: undefined };
    }
    simulateClickEvent(input) {
        const evt = new MouseEvent('click');
        evt.stopPropagation();
        input.dispatchEvent(evt);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: SelectFiles, deps: [{ token: i1.I18nService }, { token: DOCUMENT }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: SelectFiles }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: SelectFiles, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.I18nService }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }] });

class SliceUploadService {
    constructor() {
        this.defaultChunkSize = 1024 * 1024 * 20; // 单位是byte 默认分片大小 20兆。
    }
    isNeedChunk(fileUploaders, uploadOptions) {
        return (fileUploaders || []).some((item) => item?.file.size > (uploadOptions?.chunkSize || this.defaultChunkSize));
    }
    async sliceUpload(instance, viewInstance) {
        const fileUploaders = viewInstance.fileUploaders;
        const customizeFunc = instance.dynamicUploadOptionsFn || instance.setCustomUploadOptions;
        for (let i = 0; i < fileUploaders.length; i++) {
            // 判断不需要切片的文件不调用自定义参数方法
            const file = fileUploaders[i].file;
            const isNeedChunk = file.size > (instance.uploadOptions?.chunkSize || this.defaultChunkSize);
            const fileChunkList = this.createFileChunk(file, fileUploaders[i].uploadOptions || instance.uploadOptions, isNeedChunk ? customizeFunc : undefined);
            const currentFile = fileUploaders[i];
            const uploadObservable = this.uploadChunkList(fileChunkList, currentFile, instance, viewInstance);
            (await uploadObservable).subscribe((results) => {
                currentFile.percentage = 100;
                currentFile.status = UploadStatus.uploaded;
                const successRes = [
                    {
                        file: currentFile.file,
                        response: results[0].response,
                        chunkList: results,
                    },
                ];
                instance.successEvent.emit(successRes);
                results.forEach((result) => viewInstance.uploadedFilesComponent.addAndOverwriteFile(result.file));
            }, (error) => {
                error.file = currentFile.file;
                this.chunkRequestError(error, currentFile, instance, viewInstance, false);
            });
        }
    }
    async uploadChunkList(fileChunkList, currentFile, instance, viewInstance) {
        let uploads = [];
        const chunkPercentage = (1 / fileChunkList.length) * 100;
        currentFile.status = UploadStatus.uploading;
        currentFile.percentage = 0;
        if (instance.uploadOptions.chunkInSequence) {
            return of(...fileChunkList).pipe(concatMap((uploader) => {
                let result;
                if (currentFile.status === UploadStatus.failed) {
                    result = from(Promise.reject(new Error('upload canceled')));
                    if (uploads.length === 0) {
                        uploads.push(result);
                    }
                }
                else {
                    result = from(uploader.send());
                    result.subscribe(() => {
                        currentFile.percentage = currentFile.percentage + chunkPercentage;
                    }, (error) => this.chunkRequestError(error, currentFile, instance, viewInstance));
                    uploads.push(result);
                }
                return result;
            }), 
            // last的过滤函数直接返回false，从而使用默认值uploads返回
            last(() => false, uploads));
        }
        else {
            uploads = fileChunkList.map((fileUploader) => {
                fileUploader.percentage = 0;
                return from(fileUploader.send());
            });
            if (uploads.length > 0) {
                const uploadObservable = merge(...uploads);
                (await uploadObservable).subscribe((results) => {
                    currentFile.percentage = currentFile.percentage + chunkPercentage;
                }, (error) => this.chunkRequestError(error, currentFile, instance, viewInstance));
                return merge(...uploads).pipe(toArray());
            }
        }
        return from(Promise.reject(new Error('no files')));
    }
    // 生成分片上传的数组
    createFileChunk(file, uploadOptions, uploadOptionsFunc) {
        const chunkSize = uploadOptions.chunkSize || this.defaultChunkSize;
        const { name, type, lastModified, size } = file;
        const fileId = new Date().getTime();
        const fileChunkList = [];
        let fileSliceStart = 0;
        let chunkedFileIndex = 0;
        const chunks = Math.ceil(size / chunkSize);
        while (fileSliceStart < file.size) {
            chunkedFileIndex = chunkedFileIndex + 1;
            const currentUploadOptions = uploadOptionsFunc?.(file, uploadOptions, chunkedFileIndex) || uploadOptions;
            const slicedFile = file.slice(fileSliceStart, fileSliceStart + chunkSize);
            const newChunkFile = new File([slicedFile], `${fileId}-${chunkedFileIndex}-${chunks}-${size}-${lastModified}-${name}`, { type });
            fileChunkList.push(new FileUploader(newChunkFile, currentUploadOptions));
            fileSliceStart += chunkSize;
        }
        return fileChunkList;
    }
    chunkRequestError(error, currentFile, instance, viewInstance, isChunk = true) {
        currentFile.status = UploadStatus.failed;
        viewInstance.uploadedFilesComponent.cleanUploadedFiles();
        if (isChunk) {
            instance.errorChunkEvent.emit(error);
        }
        else {
            instance.errorEvent.emit(error);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: SliceUploadService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: SliceUploadService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: SliceUploadService, decorators: [{
            type: Injectable
        }] });

class MultipleUploadComponent {
    get hasGlowStyle() {
        return this.showGlowStyle;
    }
    constructor(selectFiles, i18n, doc, sliceUploadService, devConfigService, toastService) {
        this.selectFiles = selectFiles;
        this.i18n = i18n;
        this.doc = doc;
        this.sliceUploadService = sliceUploadService;
        this.devConfigService = devConfigService;
        this.toastService = toastService;
        this.autoUpload = false;
        this.withoutBtn = false;
        this.showTip = false;
        this.uploadedFiles = [];
        this.oneTimeUpload = false;
        this.disabled = false;
        this.enableDrop = false;
        this.showGlowStyle = true;
        this.successEvent = new EventEmitter();
        this.errorEvent = new EventEmitter();
        this.errorChunkEvent = new EventEmitter();
        this.deleteUploadedFileEvent = new EventEmitter();
        this.fileDrop = new EventEmitter();
        this.fileOver = new EventEmitter();
        this.fileSelect = new EventEmitter();
        this.isDropOVer = false;
        this.errorMsg = [];
        this.UploadStatus = UploadStatus;
        this.onChange = (_) => null;
        this.onTouched = () => null;
        this.document = this.doc;
    }
    ngOnInit() {
        this.i18nText = this.i18n.getI18nText().upload;
        this.i18nCommonText = this.i18n.getI18nText().common;
        this.i18nSubscription = this.i18n.langChange().subscribe((data) => {
            this.i18nText = data.upload;
            this.i18nCommonText = data.common;
        });
    }
    writeValue(files) {
        if (files) {
            const simulateFiles = from(this.simulateSelectFiles(files)).pipe(mergeMap((file) => file));
            this._dealFiles(simulateFiles);
        }
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    simulateSelectFiles(files) {
        return new Promise((resolve) => {
            resolve(Array.prototype.slice.call(files));
        });
    }
    _dealFiles(observale) {
        this.multipleUploadViewComponent.resetSameNameFiles();
        observale
            .pipe(map((file) => this.multipleUploadViewComponent.addFile(file)), debounceTime(100))
            .subscribe(() => {
            this.checkValid();
            const sameNameFiles = this.multipleUploadViewComponent.getSameNameFiles();
            if (this.uploadOptions.checkSameName && sameNameFiles.length) {
                this.alertMsg(this.i18nText.getExistSameNameFilesMsg(sameNameFiles));
            }
            this.onChange(this.multipleUploadViewComponent.fileUploaders.map((fileUploader) => fileUploader.file));
            const selectedFiles = this.multipleUploadViewComponent.fileUploaders
                .filter((fileUploader) => fileUploader.status === UploadStatus.preLoad)
                .map((fileUploader) => fileUploader.file);
            this.onFileSelect(selectedFiles);
            if (this.autoUpload) {
                this.upload();
            }
        }, (error) => {
            this.alertMsg(error.message);
        });
    }
    checkValid() {
        let totalFileSize = 0;
        this.multipleUploadViewComponent.fileUploaders.forEach((fileUploader) => {
            totalFileSize += fileUploader.file.size;
            const checkResult = this.selectFiles._validateFiles(this.multipleUploadViewComponent.fileUploaders.length, fileUploader.file, this.fileOptions.accept, fileUploader.uploadOptions);
            if (checkResult && checkResult.checkError) {
                this.multipleUploadViewComponent.deletePreUploadFile(fileUploader.file);
                this.alertMsg(checkResult.errorMsg);
                return;
            }
        });
        if (this.oneTimeUpload) {
            const checkResult = this.selectFiles.checkAllFilesSize(totalFileSize, this.uploadOptions.maximumSize);
            if (checkResult && checkResult.checkError) {
                this.multipleUploadViewComponent.removeFiles();
                this.alertMsg(checkResult.errorMsg);
            }
        }
    }
    onClick(event) {
        if (this.disabled) {
            return;
        }
        this._dealFiles(this.selectFiles.triggerSelectFiles(this.fileOptions, this.uploadOptions));
    }
    onFileDrop(files) {
        this.isDropOVer = false;
        this._dealFiles(this.selectFiles.triggerDropFiles(this.fileOptions, this.uploadOptions, files));
        this.fileDrop.emit(files);
    }
    onFileOver(event) {
        this.isDropOVer = event;
        this.fileOver.emit(event);
    }
    onFileSelect(files) {
        this.fileSelect.emit(files);
    }
    handleOneTimeUpload(uploadObservable) {
        uploadObservable.pipe(last()).subscribe((results) => {
            this.successEvent.emit(results);
            results.forEach((result) => {
                this.multipleUploadViewComponent.uploadedFilesComponent.addFile(result.file);
            });
        }, (error) => {
            this.errorEvent.emit(error);
        });
    }
    handleUpload(uploadObservable) {
        uploadObservable.pipe(last()).subscribe((results) => {
            const successResult = results
                .filter((item) => item.status === UploadStatus.uploaded)
                .map((item) => {
                return { file: item.file, response: item.response };
            });
            const failResult = results
                .filter((item) => item.status === UploadStatus.failed)
                .map((item) => {
                return { file: item.file, response: item.response };
            });
            if (failResult.length) {
                this.errorEvent.emit(failResult);
            }
            if (successResult.length) {
                this.successEvent.emit(successResult);
                successResult.forEach((result) => {
                    this.multipleUploadViewComponent.uploadedFilesComponent.addFile(result.file);
                });
            }
        });
    }
    upload(event, fileUploader) {
        if (event) {
            event.stopPropagation();
        }
        this.canUpload().then((canUpload) => {
            if (!canUpload) {
                this.multipleUploadViewComponent.removeFiles();
                return;
            }
            const tempNode = this.document.getElementById('d-upload-temp');
            if (tempNode) {
                this.document.body.removeChild(tempNode);
            }
            if (this.uploadOptions.isChunked &&
                this.sliceUploadService.isNeedChunk(this.multipleUploadViewComponent.fileUploaders, this.uploadOptions)) {
                this.sliceUploadService.sliceUpload(this, this.multipleUploadViewComponent);
            }
            else if (this.oneTimeUpload) {
                const oneTimeUploadObservable = this.multipleUploadViewComponent.oneTimeUpload();
                this.handleOneTimeUpload(oneTimeUploadObservable);
            }
            else {
                const uploadObservable = this.multipleUploadViewComponent.upload(fileUploader, true);
                this.handleUpload(uploadObservable);
            }
        });
    }
    canUpload() {
        let uploadResult = Promise.resolve(true);
        if (this.beforeUpload) {
            const result = this.beforeUpload(this.multipleUploadViewComponent.getFullFiles());
            if (typeof result !== 'undefined') {
                if (result.then) {
                    uploadResult = result;
                }
                else if (result.subscribe) {
                    uploadResult = result.toPromise();
                }
                else {
                    uploadResult = Promise.resolve(result);
                }
            }
        }
        return uploadResult;
    }
    _onDeleteUploadedFile(filePath) {
        this.deleteUploadedFileEvent.emit(filePath);
        this.onChange(this.multipleUploadViewComponent.fileUploaders.map((fileUploader) => fileUploader.file));
    }
    deleteFile($event, file) {
        $event.stopPropagation();
        this.multipleUploadViewComponent.deleteFile(file);
    }
    alertMsg(errorMsg) {
        this.toastService.open({
            value: [{ severity: 'warn', content: errorMsg }],
        });
    }
    getStatus() {
        let uploadingCount = 0;
        let uploadedCount = 0;
        let failedCount = 0;
        const filesCount = this.multipleUploadViewComponent.fileUploaders.length;
        this.multipleUploadViewComponent.fileUploaders.forEach((fileUploader) => {
            if (fileUploader.status === UploadStatus.uploading) {
                uploadingCount++;
            }
            else if (fileUploader.status === UploadStatus.uploaded) {
                uploadedCount++;
            }
            else if (fileUploader.status === UploadStatus.failed) {
                failedCount++;
            }
        });
        if (failedCount > 0) {
            this.uploadTips = this.i18nText.getFailedFilesCount(failedCount);
            return 'failed';
        }
        if (uploadingCount > 0) {
            this.uploadTips = this.i18nText.getUploadingFilesCount(uploadingCount, filesCount);
            return 'uploading';
        }
        if (uploadedCount === filesCount && uploadedCount !== 0) {
            return 'uploaded';
        }
        if (filesCount !== 0) {
            this.uploadTips = this.i18nText.getSelectedFilesCount(filesCount);
            return 'selected';
        }
    }
    cancelUpload() {
        this.multipleUploadViewComponent.fileUploaders
            .filter((fileUploader) => fileUploader.status === UploadStatus.uploading)
            .forEach((fileUploader) => {
            fileUploader.status = UploadStatus.failed;
        });
    }
    ngOnDestroy() {
        if (this.i18nSubscription) {
            this.i18nSubscription.unsubscribe();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: MultipleUploadComponent, deps: [{ token: SelectFiles }, { token: i1.I18nService }, { token: DOCUMENT }, { token: SliceUploadService }, { token: i4.DevConfigService }, { token: i5.ToastService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.2.3", type: MultipleUploadComponent, selector: "d-multiple-upload", inputs: { uploadOptions: "uploadOptions", fileOptions: "fileOptions", autoUpload: "autoUpload", withoutBtn: "withoutBtn", showTip: "showTip", uploadedFiles: "uploadedFiles", uploadedFilesRef: "uploadedFilesRef", preloadFilesRef: "preloadFilesRef", filePath: "filePath", placeholderText: "placeholderText", uploadText: "uploadText", confirmText: "confirmText", oneTimeUpload: "oneTimeUpload", disabled: "disabled", beforeUpload: "beforeUpload", setCustomUploadOptions: "setCustomUploadOptions", enableDrop: "enableDrop", showGlowStyle: "showGlowStyle" }, outputs: { successEvent: "successEvent", errorEvent: "errorEvent", errorChunkEvent: "errorChunkEvent", deleteUploadedFileEvent: "deleteUploadedFileEvent", fileDrop: "fileDrop", fileOver: "fileOver", fileSelect: "fileSelect" }, host: { properties: { "class.devui-glow-style": "this.hasGlowStyle" } }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => MultipleUploadComponent),
                multi: true,
            },
        ], viewQueries: [{ propertyName: "multipleUploadViewComponent", first: true, predicate: ["dMultipleUploadView"], descendants: true, static: true }], exportAs: ["dMultipleUpload"], ngImport: i0, template: "<div\r\n  d-file-drop\r\n  [enableDrop]=\"enableDrop\"\r\n  (fileDrop)=\"onFileDrop($event)\"\r\n  (fileOver)=\"onFileOver($event)\"\r\n  (fileSelect)=\"onFileSelect($event)\"\r\n  [ngStyle]=\"{ border: isDropOVer ? '1px solid #15bf15' : '0' }\"\r\n  style=\"display: flex\"\r\n>\r\n  <div class=\"devui-input-group\" [class.disabled]=\"disabled\" [class.with-button]=\"!withoutBtn\" (click)=\"onClick($event)\">\r\n    <div *ngIf=\"dMultipleUploadView.fileUploaders.length === 0\" class=\"devui-form-control devui-upload-placeholder\">\r\n      {{ placeholderText ? placeholderText : i18nText?.chooseFile }}\r\n    </div>\r\n    <ul *ngIf=\"dMultipleUploadView.fileUploaders.length > 0\" class=\"devui-form-control devui-files-list\">\r\n      <li\r\n        *ngFor=\"let fileUploader of dMultipleUploadView.fileUploaders; let index = index\"\r\n        class=\"devui-file-item devui-file-tag\"\r\n        style=\"display: inline-block; margin: 0 2px 2px 0\"\r\n        title=\"{{ fileUploader.file.name }}\"\r\n      >\r\n        <span class=\"devui-filename {{ fileUploader.status === UploadStatus.failed ? 'devui-failed-color' : '' }}\">\r\n          {{ fileUploader.file.name }}\r\n        </span>\r\n        <span\r\n          class=\"icon devui-upload-remove {{ fileUploader.status === UploadStatus.failed ? 'devui-upload-delete-file-button' : '' }}\r\n          {{\r\n            fileUploader.status === UploadStatus.uploading || fileUploader.status === UploadStatus.uploaded ? 'devui-uploading-delete' : ''\r\n          }}\"\r\n          (click)=\"deleteFile($event, fileUploader.file)\"\r\n        >\r\n          <svg\r\n            width=\"16px\"\r\n            height=\"16px\"\r\n            viewBox=\"0 0 16 16\"\r\n            version=\"1.1\"\r\n            xmlns=\"http://www.w3.org/2000/svg\"\r\n            xmlns:xlink=\"http://www.w3.org/1999/xlink\"\r\n          >\r\n            <g stroke=\"none\" stroke-width=\"1\" fill=\"none\" fill-rule=\"evenodd\">\r\n              <g transform=\"translate(-270.000000, -2376.000000)\">\r\n                <g transform=\"translate(198.000000, 1991.000000)\">\r\n                  <g transform=\"translate(0.000000, 383.000000)\">\r\n                    <g transform=\"translate(72.000000, 2.000000)\">\r\n                      <path\r\n                        d=\"M4.570404,4.06442993 L4.6207661,4.10650663 L8,7.48581818 L11.3792339,4.10650663 C11.5212427,3.96449779 11.7514845,3.96449779 11.8934934,4.10650663 C12.0197234,4.2327367 12.033749,4.42868172 11.9355701,4.570404 L11.8934934,4.6207661 L8.51418182,8 L11.8934934,11.3792339 C12.0355022,11.5212427 12.0355022,11.7514845 11.8934934,11.8934934 C11.7672633,12.0197234 11.5713183,12.033749 11.429596,11.9355701 L11.3792339,11.8934934 L8,8.51418182 L4.6207661,11.8934934 C4.47875727,12.0355022 4.24851546,12.0355022 4.10650663,11.8934934 C3.98027655,11.7672633 3.96625099,11.5713183 4.06442993,11.429596 L4.10650663,11.3792339 L7.48581818,8 L4.10650663,4.6207661 C3.96449779,4.47875727 3.96449779,4.24851546 4.10650663,4.10650663 C4.2327367,3.98027655 4.42868172,3.96625099 4.570404,4.06442993 Z\"\r\n                      ></path>\r\n                    </g>\r\n                  </g>\r\n                </g>\r\n              </g>\r\n            </g>\r\n          </svg>\r\n        </span>\r\n        <div *ngIf=\"fileUploader.status === UploadStatus.uploading\" class=\"icon devui-upload-progress\">\r\n          <d-progress\r\n            [type]=\"'circle'\"\r\n            [percentage]=\"fileUploader.percentage\"\r\n            [strokeColor]=\"'#50D4AB'\"\r\n            [strokeWidth]=\"8\"\r\n            [showContent]=\"false\"\r\n          >\r\n          </d-progress>\r\n        </div>\r\n        <span *ngIf=\"fileUploader.status === UploadStatus.failed\" class=\"icon icon-running\" (click)=\"upload($event, fileUploader)\"> </span>\r\n        <span *ngIf=\"fileUploader.status === UploadStatus.uploaded\" class=\"icon icon-right\"></span>\r\n      </li>\r\n    </ul>\r\n    <span class=\"devui-input-group-addon\">\r\n      <svg class=\"svg-icon-dot\" height=\"1em\" width=\"1em\" viewBox=\"0 0 1024 1024\" xmlns=\"http://www.w3.org/2000/svg\">\r\n        <path\r\n          d=\"m400.31892 176.970574c0-61.574381 50.113351-111.680569 111.679545-111.680569 61.576427 0 111.680569 50.106188 111.680569 111.680569 0 61.568241-50.104141 111.679545-111.680569 111.679545-61.566194 0-111.679545-50.111304-111.679545-111.679545zm0 335.028403c0-61.568241 50.113351-111.678522 111.679545-111.678522 61.576427 0 111.680569 50.110281 111.680569 111.678522 0 61.574381-50.105165 111.682615-111.680569 111.682615-61.566194 0-111.679545-50.108235-111.679545-111.682615zm0 335.037612c0-61.572334 50.113351-111.679545 111.679545-111.679545 61.575404 0 111.680569 50.107211 111.680569 111.679545 0 61.567217-50.105165 111.672382-111.680569 111.672382-61.566194 0-111.679545-50.105164-111.679545-111.672382zm0 0\"\r\n        />\r\n      </svg>\r\n    </span>\r\n  </div>\r\n  <d-button\r\n    *ngIf=\"!autoUpload && !withoutBtn\"\r\n    [disabled]=\"disabled\"\r\n    (btnClick)=\"upload($event)\"\r\n    [style.margin-left.px]=\"8\"\r\n    bsStyle=\"common\"\r\n  >\r\n    {{ uploadText || i18nText?.upload }}\r\n  </d-button>\r\n</div>\r\n<ng-container *ngIf=\"showTip\">\r\n  <div class=\"devui-upload-tip\">\r\n    <span *ngIf=\"getStatus() === 'selected'\" class=\"devui-loading\">{{ uploadTips }}</span>\r\n    <span *ngIf=\"getStatus() === 'uploading'\" class=\"devui-loading\">\r\n      <span style=\"margin-right: 8px\">{{ uploadTips }}</span>\r\n      <a (click)=\"cancelUpload()\">{{ i18nText?.cancelUpload }}</a>\r\n    </span>\r\n    <div *ngIf=\"getStatus() === 'uploaded'\" class=\"devui-loaded\">\r\n      <i class=\"icon icon-right-o\"></i>\r\n      <span style=\"vertical-align: middle\">{{ i18nText?.uploadSuccess }}</span>\r\n    </div>\r\n    <div *ngIf=\"getStatus() === 'failed'\" class=\"devui-upload-failed\">\r\n      <i class=\"icon icon-info-o\"></i>\r\n      <span style=\"vertical-align: middle\">\r\n        <span style=\"margin-right: 8px\">{{ uploadTips }}</span>\r\n        <a (click)=\"upload($event)\">{{ i18nText?.reUpload }}</a>\r\n      </span>\r\n    </div>\r\n  </div>\r\n</ng-container>\r\n<d-multiple-upload-view\r\n  #dMultipleUploadView\r\n  [uploadedFiles]=\"uploadedFiles\"\r\n  [uploadedFilesRef]=\"uploadedFilesRef\"\r\n  [preloadFilesRef]=\"preloadFilesRef\"\r\n  [uploadOptions]=\"uploadOptions\"\r\n  [filePath]=\"filePath\"\r\n  [setCustomUploadOptions]=\"setCustomUploadOptions\"\r\n  (deleteUploadedFileEvent)=\"_onDeleteUploadedFile($event)\"\r\n>\r\n</d-multiple-upload-view>\r\n", styles: [".devui-font-size-base{font-size:var(--devui-font-size, 12px)}.devui-font-base{font-size:var(--devui-font-size, 12px);font-weight:var(--devui-font-content-weight, normal);line-height:var(--devui-line-height-base, 1.5)}.devui-font-size-modal-title{font-size:var(--devui-font-size-modal-title, 18px)}.devui-font-modal-title{font-size:var(--devui-font-size-modal-title, 18px);font-weight:var(--devui-font-title-weight, bold);line-height:var(--devui-line-height-base, 1.5)}.devui-font-size-page-title{font-size:var(--devui-font-size-page-title, 16px)}.devui-font-page-title{font-size:var(--devui-font-size-page-title, 16px);font-weight:var(--devui-font-title-weight, bold);line-height:var(--devui-line-height-base, 1.5)}.devui-font-size-secondary-title{font-size:var(--devui-font-size-card-title, 14px)}.devui-font-secondary-title{font-size:var(--devui-font-size-card-title, 14px);font-weight:var(--devui-font-title-weight, bold);line-height:var(--devui-line-height-base, 1.5)}.devui-input-group{position:relative;display:flex;align-items:center;border-collapse:separate;width:100%;border-radius:var(--devui-border-radius, 2px)}.devui-input-group:not(.disabled):hover .devui-input-group-addon{background-color:var(--devui-dividing-line, #eef0f5);font-weight:700}.devui-input-group:not(.disabled):hover .devui-form-control{border-right-color:var(--devui-form-control-line, #d7d8da)}.devui-input-group:not(.disabled) .devui-input-group-addon:active{border-color:var(--devui-form-control-line-active, #5e7ce0);border-right-color:var(--devui-form-control-line, #d7d8da);background-color:var(--devui-dividing-line, #eef0f5)}.devui-input-group .devui-input-group-addon{width:36px;white-space:nowrap;font-size:var(--devui-font-size-icon, 16px);font-weight:400;line-height:1;color:var(--devui-text, #252b3a);background-color:var(--devui-area, #f5f5f5);border-top:1px solid var(--devui-form-control-line, #d7d8da);border-bottom:1px solid var(--devui-form-control-line, #d7d8da);border-right:1px solid var(--devui-form-control-line, #d7d8da);border-radius:0 var(--devui-border-radius, 2px) var(--devui-border-radius, 2px) 0;transition:border-color var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1)),background-color var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1));cursor:pointer;height:100%;position:relative;display:inline-block}.devui-input-group .devui-input-group-addon svg{position:absolute;left:50%;top:50%;transform:translate(-50%,-50%)}.devui-input-group .devui-form-control{cursor:pointer;display:block;width:100%;min-height:28px;height:unset;padding:4px 8px;font-size:var(--devui-font-size, 12px);line-height:1.5;background-image:none;border:1px solid var(--devui-form-control-line, #d7d8da);border-radius:var(--devui-border-radius, 2px) 0 0 var(--devui-border-radius, 2px);transition:border-color var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1)),box-shadow var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1))}.devui-input-group .devui-form-control.devui-files-list{max-height:52px;padding:2px 2px 0;overflow-x:hidden;overflow-y:auto;max-width:100%}.devui-input-group .devui-form-control.devui-files-list .devui-file-item{height:22px;line-height:22px;padding:0 48px 0 12px}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag{position:relative;background-color:var(--devui-label-bg, #e9edfa);border-radius:var(--devui-border-radius, 2px);max-width:100%}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .devui-filename{height:100%;display:inline-block;vertical-align:middle;max-width:100%;overflow:hidden;white-space:nowrap;text-overflow:ellipsis}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon{position:absolute;cursor:pointer;right:8px;top:50%;transform:translateY(-50%);line-height:1}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon.icon-right{color:var(--devui-success, #3ac295)}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon.icon-running{font-size:16px}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon.devui-upload-delete-file-button{margin-right:20px}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon.devui-uploading-delete{display:none}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon.devui-upload-remove{width:16px;height:16px}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon.devui-upload-remove svg path{fill:var(--devui-text, #252b3a)}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag:hover .devui-upload-progress,.devui-input-group .devui-form-control.devui-files-list .devui-file-tag:hover .icon-right{display:none}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag:hover .devui-upload-remove{display:inline-block}.devui-input-group.disabled .devui-upload-placeholder{color:var(--devui-disabled-text, #babbc0)}.devui-input-group .devui-upload-placeholder{max-height:28px;max-width:100%;overflow:hidden;white-space:nowrap;text-overflow:ellipsis;color:var(--devui-placeholder, #babbc0)}:host ::ng-deep .devui-upload-progress{width:16px;height:16px}.devui-input-group.disabled .devui-form-control,.devui-input-group.disabled .devui-input-group-addon{cursor:not-allowed;background-color:var(--devui-disabled-bg, #f5f5f5);border-color:var(--devui-disabled-line, #dfe1e6);color:var(--devui-disabled-text, #babbc0)}svg.svg-icon-dot>path{fill:var(--devui-icon-text, #71757f)}.devui-form-control{outline:none}.devui-input-group.disabled .devui-upload-delete-file-button{cursor:not-allowed;pointer-events:none}.devui-loading{color:var(--devui-aide-text, #71757f)}.devui-failed-color{color:var(--devui-danger, #f66f6a)}.devui-upload-tip{height:18px;margin-top:8px;font-size:12px}.devui-upload-tip .icon{margin-right:8px;font-size:16px;vertical-align:middle}.devui-upload-tip .icon-right-o{color:var(--devui-success, #3ac295)}.devui-upload-tip .devui-upload-failed{color:var(--devui-danger, #f66f6a)}.devui-upload-tip a{color:var(--devui-link, #526ecc);cursor:pointer}.with-button{max-width:calc(100% - 72px)}\n"], dependencies: [{ kind: "directive", type: i6.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i6.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i6.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { kind: "component", type: i7.ButtonComponent, selector: "d-button", inputs: ["id", "type", "bsStyle", "shape", "bsSize", "bsPosition", "bordered", "icon", "disabled", "showLoading", "width", "autofocus", "loadingTemplateRef"], outputs: ["btnClick"] }, { kind: "component", type: i8.ProgressComponent, selector: "d-progress", inputs: ["isDynamic", "percentage", "percentageText", "barbgcolor", "strokeColor", "height", "strokeWidth", "isCircle", "type", "showContent", "multiProgressConfig"] }, { kind: "component", type: MultipleUploadViewComponent, selector: "d-multiple-upload-view", inputs: ["uploadOptions", "preloadFilesRef", "uploadedFiles", "uploadedFilesRef", "filePath", "setCustomUploadOptions"], outputs: ["deleteUploadedFileEvent"] }, { kind: "directive", type: FileDropDirective, selector: "[d-file-drop]", inputs: ["enableDrop", "isSingle"], outputs: ["fileOver", "fileDrop"] }] }); }
}
__decorate([
    WithConfig(),
    __metadata("design:type", Object)
], MultipleUploadComponent.prototype, "showGlowStyle", void 0);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: MultipleUploadComponent, decorators: [{
            type: Component,
            args: [{ selector: 'd-multiple-upload', exportAs: 'dMultipleUpload', preserveWhitespaces: false, providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => MultipleUploadComponent),
                            multi: true,
                        },
                    ], template: "<div\r\n  d-file-drop\r\n  [enableDrop]=\"enableDrop\"\r\n  (fileDrop)=\"onFileDrop($event)\"\r\n  (fileOver)=\"onFileOver($event)\"\r\n  (fileSelect)=\"onFileSelect($event)\"\r\n  [ngStyle]=\"{ border: isDropOVer ? '1px solid #15bf15' : '0' }\"\r\n  style=\"display: flex\"\r\n>\r\n  <div class=\"devui-input-group\" [class.disabled]=\"disabled\" [class.with-button]=\"!withoutBtn\" (click)=\"onClick($event)\">\r\n    <div *ngIf=\"dMultipleUploadView.fileUploaders.length === 0\" class=\"devui-form-control devui-upload-placeholder\">\r\n      {{ placeholderText ? placeholderText : i18nText?.chooseFile }}\r\n    </div>\r\n    <ul *ngIf=\"dMultipleUploadView.fileUploaders.length > 0\" class=\"devui-form-control devui-files-list\">\r\n      <li\r\n        *ngFor=\"let fileUploader of dMultipleUploadView.fileUploaders; let index = index\"\r\n        class=\"devui-file-item devui-file-tag\"\r\n        style=\"display: inline-block; margin: 0 2px 2px 0\"\r\n        title=\"{{ fileUploader.file.name }}\"\r\n      >\r\n        <span class=\"devui-filename {{ fileUploader.status === UploadStatus.failed ? 'devui-failed-color' : '' }}\">\r\n          {{ fileUploader.file.name }}\r\n        </span>\r\n        <span\r\n          class=\"icon devui-upload-remove {{ fileUploader.status === UploadStatus.failed ? 'devui-upload-delete-file-button' : '' }}\r\n          {{\r\n            fileUploader.status === UploadStatus.uploading || fileUploader.status === UploadStatus.uploaded ? 'devui-uploading-delete' : ''\r\n          }}\"\r\n          (click)=\"deleteFile($event, fileUploader.file)\"\r\n        >\r\n          <svg\r\n            width=\"16px\"\r\n            height=\"16px\"\r\n            viewBox=\"0 0 16 16\"\r\n            version=\"1.1\"\r\n            xmlns=\"http://www.w3.org/2000/svg\"\r\n            xmlns:xlink=\"http://www.w3.org/1999/xlink\"\r\n          >\r\n            <g stroke=\"none\" stroke-width=\"1\" fill=\"none\" fill-rule=\"evenodd\">\r\n              <g transform=\"translate(-270.000000, -2376.000000)\">\r\n                <g transform=\"translate(198.000000, 1991.000000)\">\r\n                  <g transform=\"translate(0.000000, 383.000000)\">\r\n                    <g transform=\"translate(72.000000, 2.000000)\">\r\n                      <path\r\n                        d=\"M4.570404,4.06442993 L4.6207661,4.10650663 L8,7.48581818 L11.3792339,4.10650663 C11.5212427,3.96449779 11.7514845,3.96449779 11.8934934,4.10650663 C12.0197234,4.2327367 12.033749,4.42868172 11.9355701,4.570404 L11.8934934,4.6207661 L8.51418182,8 L11.8934934,11.3792339 C12.0355022,11.5212427 12.0355022,11.7514845 11.8934934,11.8934934 C11.7672633,12.0197234 11.5713183,12.033749 11.429596,11.9355701 L11.3792339,11.8934934 L8,8.51418182 L4.6207661,11.8934934 C4.47875727,12.0355022 4.24851546,12.0355022 4.10650663,11.8934934 C3.98027655,11.7672633 3.96625099,11.5713183 4.06442993,11.429596 L4.10650663,11.3792339 L7.48581818,8 L4.10650663,4.6207661 C3.96449779,4.47875727 3.96449779,4.24851546 4.10650663,4.10650663 C4.2327367,3.98027655 4.42868172,3.96625099 4.570404,4.06442993 Z\"\r\n                      ></path>\r\n                    </g>\r\n                  </g>\r\n                </g>\r\n              </g>\r\n            </g>\r\n          </svg>\r\n        </span>\r\n        <div *ngIf=\"fileUploader.status === UploadStatus.uploading\" class=\"icon devui-upload-progress\">\r\n          <d-progress\r\n            [type]=\"'circle'\"\r\n            [percentage]=\"fileUploader.percentage\"\r\n            [strokeColor]=\"'#50D4AB'\"\r\n            [strokeWidth]=\"8\"\r\n            [showContent]=\"false\"\r\n          >\r\n          </d-progress>\r\n        </div>\r\n        <span *ngIf=\"fileUploader.status === UploadStatus.failed\" class=\"icon icon-running\" (click)=\"upload($event, fileUploader)\"> </span>\r\n        <span *ngIf=\"fileUploader.status === UploadStatus.uploaded\" class=\"icon icon-right\"></span>\r\n      </li>\r\n    </ul>\r\n    <span class=\"devui-input-group-addon\">\r\n      <svg class=\"svg-icon-dot\" height=\"1em\" width=\"1em\" viewBox=\"0 0 1024 1024\" xmlns=\"http://www.w3.org/2000/svg\">\r\n        <path\r\n          d=\"m400.31892 176.970574c0-61.574381 50.113351-111.680569 111.679545-111.680569 61.576427 0 111.680569 50.106188 111.680569 111.680569 0 61.568241-50.104141 111.679545-111.680569 111.679545-61.566194 0-111.679545-50.111304-111.679545-111.679545zm0 335.028403c0-61.568241 50.113351-111.678522 111.679545-111.678522 61.576427 0 111.680569 50.110281 111.680569 111.678522 0 61.574381-50.105165 111.682615-111.680569 111.682615-61.566194 0-111.679545-50.108235-111.679545-111.682615zm0 335.037612c0-61.572334 50.113351-111.679545 111.679545-111.679545 61.575404 0 111.680569 50.107211 111.680569 111.679545 0 61.567217-50.105165 111.672382-111.680569 111.672382-61.566194 0-111.679545-50.105164-111.679545-111.672382zm0 0\"\r\n        />\r\n      </svg>\r\n    </span>\r\n  </div>\r\n  <d-button\r\n    *ngIf=\"!autoUpload && !withoutBtn\"\r\n    [disabled]=\"disabled\"\r\n    (btnClick)=\"upload($event)\"\r\n    [style.margin-left.px]=\"8\"\r\n    bsStyle=\"common\"\r\n  >\r\n    {{ uploadText || i18nText?.upload }}\r\n  </d-button>\r\n</div>\r\n<ng-container *ngIf=\"showTip\">\r\n  <div class=\"devui-upload-tip\">\r\n    <span *ngIf=\"getStatus() === 'selected'\" class=\"devui-loading\">{{ uploadTips }}</span>\r\n    <span *ngIf=\"getStatus() === 'uploading'\" class=\"devui-loading\">\r\n      <span style=\"margin-right: 8px\">{{ uploadTips }}</span>\r\n      <a (click)=\"cancelUpload()\">{{ i18nText?.cancelUpload }}</a>\r\n    </span>\r\n    <div *ngIf=\"getStatus() === 'uploaded'\" class=\"devui-loaded\">\r\n      <i class=\"icon icon-right-o\"></i>\r\n      <span style=\"vertical-align: middle\">{{ i18nText?.uploadSuccess }}</span>\r\n    </div>\r\n    <div *ngIf=\"getStatus() === 'failed'\" class=\"devui-upload-failed\">\r\n      <i class=\"icon icon-info-o\"></i>\r\n      <span style=\"vertical-align: middle\">\r\n        <span style=\"margin-right: 8px\">{{ uploadTips }}</span>\r\n        <a (click)=\"upload($event)\">{{ i18nText?.reUpload }}</a>\r\n      </span>\r\n    </div>\r\n  </div>\r\n</ng-container>\r\n<d-multiple-upload-view\r\n  #dMultipleUploadView\r\n  [uploadedFiles]=\"uploadedFiles\"\r\n  [uploadedFilesRef]=\"uploadedFilesRef\"\r\n  [preloadFilesRef]=\"preloadFilesRef\"\r\n  [uploadOptions]=\"uploadOptions\"\r\n  [filePath]=\"filePath\"\r\n  [setCustomUploadOptions]=\"setCustomUploadOptions\"\r\n  (deleteUploadedFileEvent)=\"_onDeleteUploadedFile($event)\"\r\n>\r\n</d-multiple-upload-view>\r\n", styles: [".devui-font-size-base{font-size:var(--devui-font-size, 12px)}.devui-font-base{font-size:var(--devui-font-size, 12px);font-weight:var(--devui-font-content-weight, normal);line-height:var(--devui-line-height-base, 1.5)}.devui-font-size-modal-title{font-size:var(--devui-font-size-modal-title, 18px)}.devui-font-modal-title{font-size:var(--devui-font-size-modal-title, 18px);font-weight:var(--devui-font-title-weight, bold);line-height:var(--devui-line-height-base, 1.5)}.devui-font-size-page-title{font-size:var(--devui-font-size-page-title, 16px)}.devui-font-page-title{font-size:var(--devui-font-size-page-title, 16px);font-weight:var(--devui-font-title-weight, bold);line-height:var(--devui-line-height-base, 1.5)}.devui-font-size-secondary-title{font-size:var(--devui-font-size-card-title, 14px)}.devui-font-secondary-title{font-size:var(--devui-font-size-card-title, 14px);font-weight:var(--devui-font-title-weight, bold);line-height:var(--devui-line-height-base, 1.5)}.devui-input-group{position:relative;display:flex;align-items:center;border-collapse:separate;width:100%;border-radius:var(--devui-border-radius, 2px)}.devui-input-group:not(.disabled):hover .devui-input-group-addon{background-color:var(--devui-dividing-line, #eef0f5);font-weight:700}.devui-input-group:not(.disabled):hover .devui-form-control{border-right-color:var(--devui-form-control-line, #d7d8da)}.devui-input-group:not(.disabled) .devui-input-group-addon:active{border-color:var(--devui-form-control-line-active, #5e7ce0);border-right-color:var(--devui-form-control-line, #d7d8da);background-color:var(--devui-dividing-line, #eef0f5)}.devui-input-group .devui-input-group-addon{width:36px;white-space:nowrap;font-size:var(--devui-font-size-icon, 16px);font-weight:400;line-height:1;color:var(--devui-text, #252b3a);background-color:var(--devui-area, #f5f5f5);border-top:1px solid var(--devui-form-control-line, #d7d8da);border-bottom:1px solid var(--devui-form-control-line, #d7d8da);border-right:1px solid var(--devui-form-control-line, #d7d8da);border-radius:0 var(--devui-border-radius, 2px) var(--devui-border-radius, 2px) 0;transition:border-color var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1)),background-color var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1));cursor:pointer;height:100%;position:relative;display:inline-block}.devui-input-group .devui-input-group-addon svg{position:absolute;left:50%;top:50%;transform:translate(-50%,-50%)}.devui-input-group .devui-form-control{cursor:pointer;display:block;width:100%;min-height:28px;height:unset;padding:4px 8px;font-size:var(--devui-font-size, 12px);line-height:1.5;background-image:none;border:1px solid var(--devui-form-control-line, #d7d8da);border-radius:var(--devui-border-radius, 2px) 0 0 var(--devui-border-radius, 2px);transition:border-color var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1)),box-shadow var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1))}.devui-input-group .devui-form-control.devui-files-list{max-height:52px;padding:2px 2px 0;overflow-x:hidden;overflow-y:auto;max-width:100%}.devui-input-group .devui-form-control.devui-files-list .devui-file-item{height:22px;line-height:22px;padding:0 48px 0 12px}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag{position:relative;background-color:var(--devui-label-bg, #e9edfa);border-radius:var(--devui-border-radius, 2px);max-width:100%}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .devui-filename{height:100%;display:inline-block;vertical-align:middle;max-width:100%;overflow:hidden;white-space:nowrap;text-overflow:ellipsis}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon{position:absolute;cursor:pointer;right:8px;top:50%;transform:translateY(-50%);line-height:1}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon.icon-right{color:var(--devui-success, #3ac295)}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon.icon-running{font-size:16px}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon.devui-upload-delete-file-button{margin-right:20px}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon.devui-uploading-delete{display:none}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon.devui-upload-remove{width:16px;height:16px}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon.devui-upload-remove svg path{fill:var(--devui-text, #252b3a)}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag:hover .devui-upload-progress,.devui-input-group .devui-form-control.devui-files-list .devui-file-tag:hover .icon-right{display:none}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag:hover .devui-upload-remove{display:inline-block}.devui-input-group.disabled .devui-upload-placeholder{color:var(--devui-disabled-text, #babbc0)}.devui-input-group .devui-upload-placeholder{max-height:28px;max-width:100%;overflow:hidden;white-space:nowrap;text-overflow:ellipsis;color:var(--devui-placeholder, #babbc0)}:host ::ng-deep .devui-upload-progress{width:16px;height:16px}.devui-input-group.disabled .devui-form-control,.devui-input-group.disabled .devui-input-group-addon{cursor:not-allowed;background-color:var(--devui-disabled-bg, #f5f5f5);border-color:var(--devui-disabled-line, #dfe1e6);color:var(--devui-disabled-text, #babbc0)}svg.svg-icon-dot>path{fill:var(--devui-icon-text, #71757f)}.devui-form-control{outline:none}.devui-input-group.disabled .devui-upload-delete-file-button{cursor:not-allowed;pointer-events:none}.devui-loading{color:var(--devui-aide-text, #71757f)}.devui-failed-color{color:var(--devui-danger, #f66f6a)}.devui-upload-tip{height:18px;margin-top:8px;font-size:12px}.devui-upload-tip .icon{margin-right:8px;font-size:16px;vertical-align:middle}.devui-upload-tip .icon-right-o{color:var(--devui-success, #3ac295)}.devui-upload-tip .devui-upload-failed{color:var(--devui-danger, #f66f6a)}.devui-upload-tip a{color:var(--devui-link, #526ecc);cursor:pointer}.with-button{max-width:calc(100% - 72px)}\n"] }]
        }], ctorParameters: () => [{ type: SelectFiles }, { type: i1.I18nService }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }, { type: SliceUploadService }, { type: i4.DevConfigService }, { type: i5.ToastService }], propDecorators: { uploadOptions: [{
                type: Input
            }], fileOptions: [{
                type: Input
            }], autoUpload: [{
                type: Input
            }], withoutBtn: [{
                type: Input
            }], showTip: [{
                type: Input
            }], uploadedFiles: [{
                type: Input
            }], uploadedFilesRef: [{
                type: Input
            }], preloadFilesRef: [{
                type: Input
            }], filePath: [{
                type: Input
            }], placeholderText: [{
                type: Input
            }], uploadText: [{
                type: Input
            }], confirmText: [{
                type: Input
            }], oneTimeUpload: [{
                type: Input
            }], disabled: [{
                type: Input
            }], beforeUpload: [{
                type: Input
            }], setCustomUploadOptions: [{
                type: Input
            }], enableDrop: [{
                type: Input
            }], showGlowStyle: [{
                type: Input
            }], hasGlowStyle: [{
                type: HostBinding,
                args: ['class.devui-glow-style']
            }], successEvent: [{
                type: Output
            }], errorEvent: [{
                type: Output
            }], errorChunkEvent: [{
                type: Output
            }], deleteUploadedFileEvent: [{
                type: Output
            }], fileDrop: [{
                type: Output
            }], fileOver: [{
                type: Output
            }], fileSelect: [{
                type: Output
            }], multipleUploadViewComponent: [{
                type: ViewChild,
                args: ['dMultipleUploadView', { static: true }]
            }] } });

class SingleUploadViewComponent extends UploadComponent {
    constructor() {
        super(...arguments);
        this.uploadedFiles = [];
        this.deleteUploadedFileEvent = new EventEmitter();
        this.UploadStatus = UploadStatus;
        this.fileUploaders = [];
        // 解决templateContext 传递method.bind(this)引发模板中内嵌组件initialize问题
        this.deleteFileProxy = file => {
            this.deleteFile(file);
        };
    }
    addFile(file) {
        this.fileUploaders = [];
        let uploadOptions = this.uploadOptions;
        if (this.dynamicUploadOptionsFn) {
            uploadOptions = this.dynamicUploadOptionsFn(file, this.uploadOptions);
        }
        super.addFile(file, uploadOptions);
    }
    deleteFile(file) {
        super.deleteFile(file);
        this.deleteUploadedFileEvent.emit(file);
    }
    deletePreUploadFile(file) {
        super.deleteFile(file);
    }
    _onDeleteUploadedFile(filePath) {
        this.deleteUploadedFileEvent.emit(filePath);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: SingleUploadViewComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.2.3", type: SingleUploadViewComponent, selector: "d-single-upload-view", inputs: { uploadOptions: "uploadOptions", preloadFilesRef: "preloadFilesRef", uploadedFiles: "uploadedFiles", uploadedFilesRef: "uploadedFilesRef", filePath: "filePath", dynamicUploadOptionsFn: "dynamicUploadOptionsFn" }, outputs: { deleteUploadedFileEvent: "deleteUploadedFileEvent" }, viewQueries: [{ propertyName: "uploadedFilesComponent", first: true, predicate: ["dUploadedFiles"], descendants: true, static: true }], exportAs: ["dSingleUploadView"], usesInheritance: true, ngImport: i0, template: "<d-uploaded-files\n  #dUploadedFiles\n  [uploadedFiles]=\"uploadedFiles\"\n  [filePath]=\"filePath\"\n  [uploadedFilesRef]=\"uploadedFilesRef\"\n  (deleteUploadedFileEvent)=\"_onDeleteUploadedFile($event)\"\n>\n</d-uploaded-files>\n<ng-template\n  [ngTemplateOutlet]=\"preloadFilesRef\"\n  [ngTemplateOutletContext]=\"{ $implicit: this, fileUploaders: fileUploaders, UploadStatus: UploadStatus, deleteFile: deleteFileProxy }\"\n>\n</ng-template>\n", dependencies: [{ kind: "directive", type: i6.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: UploadedFilesComponent, selector: "d-uploaded-files", inputs: ["uploadedFiles", "uploadedFilesRef", "filePath"], outputs: ["deleteUploadedFileEvent"], exportAs: ["dUploadFiles"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: SingleUploadViewComponent, decorators: [{
            type: Component,
            args: [{ selector: 'd-single-upload-view', exportAs: 'dSingleUploadView', preserveWhitespaces: false, template: "<d-uploaded-files\n  #dUploadedFiles\n  [uploadedFiles]=\"uploadedFiles\"\n  [filePath]=\"filePath\"\n  [uploadedFilesRef]=\"uploadedFilesRef\"\n  (deleteUploadedFileEvent)=\"_onDeleteUploadedFile($event)\"\n>\n</d-uploaded-files>\n<ng-template\n  [ngTemplateOutlet]=\"preloadFilesRef\"\n  [ngTemplateOutletContext]=\"{ $implicit: this, fileUploaders: fileUploaders, UploadStatus: UploadStatus, deleteFile: deleteFileProxy }\"\n>\n</ng-template>\n" }]
        }], propDecorators: { uploadOptions: [{
                type: Input
            }], preloadFilesRef: [{
                type: Input
            }], uploadedFiles: [{
                type: Input
            }], uploadedFilesRef: [{
                type: Input
            }], filePath: [{
                type: Input
            }], dynamicUploadOptionsFn: [{
                type: Input
            }], deleteUploadedFileEvent: [{
                type: Output
            }], uploadedFilesComponent: [{
                type: ViewChild,
                args: ['dUploadedFiles', { static: true }]
            }] } });

class SingleUploadComponent {
    get hasGlowStyle() {
        return this.showGlowStyle;
    }
    constructor(i18n, selectFiles, doc, toastService, sliceUploadService, devConfigService) {
        this.i18n = i18n;
        this.selectFiles = selectFiles;
        this.doc = doc;
        this.toastService = toastService;
        this.sliceUploadService = sliceUploadService;
        this.devConfigService = devConfigService;
        this.autoUpload = false;
        this.withoutBtn = false;
        this.showTip = false;
        this.uploadedFiles = [];
        this.enableDrop = false;
        this.disabled = false;
        this.successEvent = new EventEmitter();
        this.errorEvent = new EventEmitter();
        this.errorChunkEvent = new EventEmitter();
        this.deleteUploadedFileEvent = new EventEmitter();
        this.fileDrop = new EventEmitter();
        this.fileOver = new EventEmitter();
        this.fileSelect = new EventEmitter();
        this.showGlowStyle = true;
        this.UploadStatus = UploadStatus;
        this.isDropOVer = false;
        this.errorMsg = [];
        this.onChange = (_) => null;
        this.onTouched = () => null;
        this.document = this.doc;
    }
    writeValue(files) {
        if (files) {
            const simulateFiles = from(this.simulateSelectFiles(files)).pipe(mergeMap((file) => file));
            this._dealFiles(simulateFiles);
        }
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    simulateSelectFiles(files) {
        return new Promise((resolve) => {
            resolve(Array.prototype.slice.call(files));
        });
    }
    ngOnInit() {
        this.i18nText = this.i18n.getI18nText().upload;
        this.i18nCommonText = this.i18n.getI18nText().common;
        this.i18nSubscription = this.i18n.langChange().subscribe((data) => {
            this.i18nText = data.upload;
            this.i18nCommonText = data.common;
        });
    }
    _dealFiles(observale) {
        observale
            .pipe(map((file) => {
            this.singleUploadViewComponent.addFile(file);
            return file;
        }))
            .subscribe(() => {
            this.singleUploadViewComponent.uploadedFilesComponent.cleanUploadedFiles();
            this.checkValid();
            const file = this.singleUploadViewComponent.fileUploaders[0]?.file;
            this.onChange(file);
            if (file) {
                this.onFileSelect(file);
            }
            if (this.autoUpload) {
                this.upload();
            }
        }, (error) => {
            this.alertMsg(error.message);
        });
    }
    checkValid() {
        this.singleUploadViewComponent.fileUploaders.forEach((fileUploader) => {
            const checkResult = this.selectFiles._validateFiles(this.singleUploadViewComponent.fileUploaders.length, fileUploader.file, this.fileOptions.accept, fileUploader.uploadOptions);
            if (checkResult.checkError) {
                this.singleUploadViewComponent.deletePreUploadFile(fileUploader.file);
                this.alertMsg(checkResult.errorMsg);
            }
        });
    }
    onClick($event) {
        if (this.disabled ||
            (this.singleUploadViewComponent.fileUploaders[0] && this.singleUploadViewComponent.fileUploaders[0].status === UploadStatus.uploading)) {
            return;
        }
        this._dealFiles(this.selectFiles.triggerSelectFiles(this.fileOptions, this.uploadOptions));
    }
    get filename() {
        return (this.singleUploadViewComponent.getFiles()[0] || {}).name || '';
    }
    onFileDrop(files) {
        this.isDropOVer = false;
        this._dealFiles(this.selectFiles.triggerDropFiles(this.fileOptions, this.uploadOptions, files));
        this.fileDrop.emit(files[0]);
    }
    onFileOver(event) {
        this.isDropOVer = event;
        this.fileOver.emit(event);
    }
    onFileSelect(file) {
        this.fileSelect.emit(file);
    }
    upload() {
        this.canUpload().then((canUpload) => {
            if (!canUpload) {
                return;
            }
            const tempNode = this.document.getElementById('d-upload-temp');
            if (tempNode) {
                this.document.body.removeChild(tempNode);
            }
            if (this.uploadOptions.isChunked &&
                this.sliceUploadService.isNeedChunk(this.singleUploadViewComponent.fileUploaders, this.uploadOptions)) {
                this.sliceUploadService.sliceUpload(this, this.singleUploadViewComponent);
            }
            else {
                this.singleUploadViewComponent
                    .upload()
                    .pipe(last())
                    .subscribe((results) => {
                    this.successEvent.emit(results);
                    results.forEach((result) => {
                        this.singleUploadViewComponent.uploadedFilesComponent.addAndOverwriteFile(result.file);
                    });
                }, (error) => {
                    if (this.singleUploadViewComponent.fileUploaders[0]) {
                        this.singleUploadViewComponent.fileUploaders[0].percentage = 0;
                    }
                    this.singleUploadViewComponent.uploadedFilesComponent.cleanUploadedFiles();
                    this.errorEvent.emit(error);
                });
            }
        });
    }
    canUpload() {
        let uploadResult = Promise.resolve(true);
        if (this.beforeUpload) {
            const result = this.beforeUpload(this.singleUploadViewComponent.getFullFiles()[0] || {});
            if (typeof result !== 'undefined') {
                if (result.then) {
                    uploadResult = result;
                }
                else if (result.subscribe) {
                    uploadResult = result.toPromise();
                }
                else {
                    uploadResult = Promise.resolve(result);
                }
            }
        }
        return uploadResult;
    }
    _onDeleteUploadedFile(filePath) {
        this.deleteUploadedFileEvent.emit(filePath);
        this.onChange(null);
    }
    deleteFile($event) {
        $event.stopPropagation();
        const files = this.singleUploadViewComponent.getFiles();
        this.singleUploadViewComponent.deleteFile(files[0]);
    }
    alertMsg(errorMsg) {
        this.toastService.open({
            value: [{ severity: 'warn', content: errorMsg }],
        });
    }
    ngOnDestroy() {
        if (this.i18nSubscription) {
            this.i18nSubscription.unsubscribe();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: SingleUploadComponent, deps: [{ token: i1.I18nService }, { token: SelectFiles }, { token: DOCUMENT }, { token: i5.ToastService }, { token: SliceUploadService }, { token: i4.DevConfigService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.2.3", type: SingleUploadComponent, selector: "d-single-upload", inputs: { uploadOptions: "uploadOptions", fileOptions: "fileOptions", autoUpload: "autoUpload", withoutBtn: "withoutBtn", showTip: "showTip", uploadedFiles: "uploadedFiles", uploadedFilesRef: "uploadedFilesRef", preloadFilesRef: "preloadFilesRef", filePath: "filePath", placeholderText: "placeholderText", uploadText: "uploadText", confirmText: "confirmText", beforeUpload: "beforeUpload", dynamicUploadOptionsFn: "dynamicUploadOptionsFn", enableDrop: "enableDrop", disabled: "disabled", showGlowStyle: "showGlowStyle" }, outputs: { successEvent: "successEvent", errorEvent: "errorEvent", errorChunkEvent: "errorChunkEvent", deleteUploadedFileEvent: "deleteUploadedFileEvent", fileDrop: "fileDrop", fileOver: "fileOver", fileSelect: "fileSelect" }, host: { properties: { "class.devui-glow-style": "this.hasGlowStyle" } }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => SingleUploadComponent),
                multi: true,
            },
        ], viewQueries: [{ propertyName: "singleUploadViewComponent", first: true, predicate: ["dSingleUploadView"], descendants: true, static: true }], exportAs: ["dSingleUpload"], ngImport: i0, template: "<div\r\n  d-file-drop\r\n  [enableDrop]=\"enableDrop\"\r\n  [isSingle]=\"true\"\r\n  (fileDrop)=\"onFileDrop($event)\"\r\n  (fileOver)=\"onFileOver($event)\"\r\n  (fileSelect)=\"onFileSelect($event)\"\r\n  [ngStyle]=\"{ border: isDropOVer ? '1px solid #15bf15' : '0' }\"\r\n  style=\"display: flex\"\r\n>\r\n  <div\r\n    class=\"devui-input-group\"\r\n    [class.disabled]=\"this.disabled || dSingleUploadView.fileUploaders[0]?.status === UploadStatus.uploading\"\r\n    [class.with-button]=\"!withoutBtn\"\r\n    (click)=\"onClick($event)\"\r\n  >\r\n    <div class=\"devui-form-control devui-files-list\">\r\n      <div *ngIf=\"!filename\" class=\"devui-file-item devui-upload-placeholder\">\r\n        {{ placeholderText ? placeholderText : i18nText?.chooseFile }}\r\n      </div>\r\n      <div *ngIf=\"!!filename\" class=\"devui-file-tag devui-file-item\" title=\"{{ filename }}\">\r\n        <span class=\"devui-filename {{ dSingleUploadView.fileUploaders[0]?.status === UploadStatus.failed ? 'devui-failed-color' : '' }}\">\r\n          {{ filename }}\r\n        </span>\r\n        <span\r\n          class=\"icon devui-upload-remove\r\n            {{ dSingleUploadView.fileUploaders[0]?.status === UploadStatus.failed ? 'devui-upload-delete-file-button' : '' }}\r\n            {{\r\n            dSingleUploadView.fileUploaders[0]?.status === UploadStatus.uploading ||\r\n            dSingleUploadView.fileUploaders[0]?.status === UploadStatus.uploaded\r\n              ? 'devui-uploading-delete'\r\n              : ''\r\n          }}\"\r\n          (click)=\"deleteFile($event)\"\r\n        >\r\n          <svg\r\n            width=\"16px\"\r\n            height=\"16px\"\r\n            viewBox=\"0 0 16 16\"\r\n            version=\"1.1\"\r\n            xmlns=\"http://www.w3.org/2000/svg\"\r\n            xmlns:xlink=\"http://www.w3.org/1999/xlink\"\r\n          >\r\n            <g stroke=\"none\" stroke-width=\"1\" fill=\"none\" fill-rule=\"evenodd\">\r\n              <g transform=\"translate(-270.000000, -2376.000000)\">\r\n                <g transform=\"translate(198.000000, 1991.000000)\">\r\n                  <g transform=\"translate(0.000000, 383.000000)\">\r\n                    <g transform=\"translate(72.000000, 2.000000)\">\r\n                      <path\r\n                        d=\"M4.570404,4.06442993 L4.6207661,4.10650663 L8,7.48581818 L11.3792339,4.10650663 C11.5212427,3.96449779 11.7514845,3.96449779 11.8934934,4.10650663 C12.0197234,4.2327367 12.033749,4.42868172 11.9355701,4.570404 L11.8934934,4.6207661 L8.51418182,8 L11.8934934,11.3792339 C12.0355022,11.5212427 12.0355022,11.7514845 11.8934934,11.8934934 C11.7672633,12.0197234 11.5713183,12.033749 11.429596,11.9355701 L11.3792339,11.8934934 L8,8.51418182 L4.6207661,11.8934934 C4.47875727,12.0355022 4.24851546,12.0355022 4.10650663,11.8934934 C3.98027655,11.7672633 3.96625099,11.5713183 4.06442993,11.429596 L4.10650663,11.3792339 L7.48581818,8 L4.10650663,4.6207661 C3.96449779,4.47875727 3.96449779,4.24851546 4.10650663,4.10650663 C4.2327367,3.98027655 4.42868172,3.96625099 4.570404,4.06442993 Z\"\r\n                      ></path>\r\n                    </g>\r\n                  </g>\r\n                </g>\r\n              </g>\r\n            </g>\r\n          </svg>\r\n        </span>\r\n        <div *ngIf=\"dSingleUploadView.fileUploaders[0]?.status === UploadStatus.uploading\" class=\"icon devui-upload-progress\">\r\n          <d-progress\r\n            [type]=\"'circle'\"\r\n            [percentage]=\"dSingleUploadView.fileUploaders[0].percentage\"\r\n            [strokeColor]=\"'#50D4AB'\"\r\n            [strokeWidth]=\"8\"\r\n            [showContent]=\"false\"\r\n          >\r\n          </d-progress>\r\n        </div>\r\n        <span *ngIf=\"dSingleUploadView.fileUploaders[0]?.status === UploadStatus.failed\" class=\"icon icon-running\" (click)=\"upload()\">\r\n        </span>\r\n        <span *ngIf=\"dSingleUploadView.fileUploaders[0]?.status === UploadStatus.uploaded\" class=\"icon icon-right\"></span>\r\n      </div>\r\n    </div>\r\n    <span class=\"devui-input-group-addon\">\r\n      <svg class=\"svg-icon-dot\" height=\"1em\" width=\"1em\" viewBox=\"0 0 1024 1024\" xmlns=\"http://www.w3.org/2000/svg\">\r\n        <path\r\n          d=\"m400.31892 176.970574c0-61.574381 50.113351-111.680569 111.679545-111.680569 61.576427 0 111.680569 50.106188 111.680569 111.680569 0 61.568241-50.104141 111.679545-111.680569 111.679545-61.566194 0-111.679545-50.111304-111.679545-111.679545zm0 335.028403c0-61.568241 50.113351-111.678522 111.679545-111.678522 61.576427 0 111.680569 50.110281 111.680569 111.678522 0 61.574381-50.105165 111.682615-111.680569 111.682615-61.566194 0-111.679545-50.108235-111.679545-111.682615zm0 335.037612c0-61.572334 50.113351-111.679545 111.679545-111.679545 61.575404 0 111.680569 50.107211 111.680569 111.679545 0 61.567217-50.105165 111.672382-111.680569 111.672382-61.566194 0-111.679545-50.105164-111.679545-111.672382zm0 0\"\r\n        />\r\n      </svg>\r\n    </span>\r\n  </div>\r\n  <d-button\r\n    *ngIf=\"!autoUpload && !withoutBtn\"\r\n    (btnClick)=\"upload()\"\r\n    bsStyle=\"common\"\r\n    [style.margin-left.px]=\"8\"\r\n    [disabled]=\"\r\n      disabled ||\r\n      dSingleUploadView.uploadedFilesComponent.uploadedFiles.length > 0 ||\r\n      dSingleUploadView.fileUploaders[0]?.status === UploadStatus.uploading\r\n    \"\r\n  >\r\n    <span *ngIf=\"!dSingleUploadView.fileUploaders[0] || dSingleUploadView.fileUploaders[0]?.status === UploadStatus.preLoad\">{{\r\n      uploadText || i18nText?.upload\r\n    }}</span>\r\n    <span *ngIf=\"dSingleUploadView.fileUploaders[0]?.status === UploadStatus.uploading\">{{ i18nText?.uploading }}</span>\r\n    <span *ngIf=\"dSingleUploadView.fileUploaders[0]?.status === UploadStatus.uploaded\">{{ i18nText?.uploaded }}</span>\r\n    <span *ngIf=\"dSingleUploadView.fileUploaders[0]?.status === UploadStatus.failed\">{{ i18nText?.uploadFailed }}</span>\r\n  </d-button>\r\n</div>\r\n<ng-container *ngIf=\"showTip\">\r\n  <div class=\"devui-upload-tip\">\r\n    <span *ngIf=\"dSingleUploadView.fileUploaders[0]?.status === UploadStatus.uploading\" class=\"devui-loading\">\r\n      {{ i18nText?.uploading }}\r\n    </span>\r\n    <div *ngIf=\"dSingleUploadView.fileUploaders[0]?.status === UploadStatus.uploaded\" class=\"devui-loaded\">\r\n      <i class=\"icon icon-right-o\"></i>\r\n      <span style=\"vertical-align: middle\">{{ i18nText?.uploadSuccess }}</span>\r\n    </div>\r\n    <div *ngIf=\"dSingleUploadView.fileUploaders[0]?.status === UploadStatus.failed\" class=\"devui-upload-failed\">\r\n      <i class=\"icon icon-info-o\"></i>\r\n      <span style=\"vertical-align: middle\">\r\n        <span style=\"margin-right: 8px\">{{ i18nText?.uploadFailed }}</span>\r\n        <a (click)=\"upload()\">{{ i18nText?.reUpload }}</a>\r\n      </span>\r\n    </div>\r\n  </div>\r\n</ng-container>\r\n<d-single-upload-view\r\n  #dSingleUploadView=\"dSingleUploadView\"\r\n  [uploadOptions]=\"uploadOptions\"\r\n  [filePath]=\"filePath\"\r\n  [uploadedFiles]=\"uploadedFiles\"\r\n  [uploadedFilesRef]=\"uploadedFilesRef\"\r\n  [preloadFilesRef]=\"preloadFilesRef\"\r\n  [dynamicUploadOptionsFn]=\"dynamicUploadOptionsFn\"\r\n  (deleteUploadedFileEvent)=\"_onDeleteUploadedFile($event)\"\r\n>\r\n</d-single-upload-view>\r\n", styles: [".devui-font-size-base{font-size:var(--devui-font-size, 12px)}.devui-font-base{font-size:var(--devui-font-size, 12px);font-weight:var(--devui-font-content-weight, normal);line-height:var(--devui-line-height-base, 1.5)}.devui-font-size-modal-title{font-size:var(--devui-font-size-modal-title, 18px)}.devui-font-modal-title{font-size:var(--devui-font-size-modal-title, 18px);font-weight:var(--devui-font-title-weight, bold);line-height:var(--devui-line-height-base, 1.5)}.devui-font-size-page-title{font-size:var(--devui-font-size-page-title, 16px)}.devui-font-page-title{font-size:var(--devui-font-size-page-title, 16px);font-weight:var(--devui-font-title-weight, bold);line-height:var(--devui-line-height-base, 1.5)}.devui-font-size-secondary-title{font-size:var(--devui-font-size-card-title, 14px)}.devui-font-secondary-title{font-size:var(--devui-font-size-card-title, 14px);font-weight:var(--devui-font-title-weight, bold);line-height:var(--devui-line-height-base, 1.5)}.devui-input-group{position:relative;display:flex;align-items:center;border-collapse:separate;width:100%;border-radius:var(--devui-border-radius, 2px)}.devui-input-group:not(.disabled):hover .devui-input-group-addon{background-color:var(--devui-dividing-line, #eef0f5);font-weight:700}.devui-input-group:not(.disabled):hover .devui-form-control{border-right-color:var(--devui-form-control-line, #d7d8da)}.devui-input-group:not(.disabled) .devui-input-group-addon:active{border-color:var(--devui-form-control-line-active, #5e7ce0);border-right-color:var(--devui-form-control-line, #d7d8da);background-color:var(--devui-dividing-line, #eef0f5)}.devui-input-group .devui-input-group-addon{width:36px;white-space:nowrap;font-size:var(--devui-font-size-icon, 16px);font-weight:400;line-height:1;color:var(--devui-text, #252b3a);background-color:var(--devui-area, #f5f5f5);border-top:1px solid var(--devui-form-control-line, #d7d8da);border-bottom:1px solid var(--devui-form-control-line, #d7d8da);border-right:1px solid var(--devui-form-control-line, #d7d8da);border-radius:0 var(--devui-border-radius, 2px) var(--devui-border-radius, 2px) 0;transition:border-color var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1)),background-color var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1));cursor:pointer;height:100%;position:relative;display:inline-block}.devui-input-group .devui-input-group-addon svg{position:absolute;left:50%;top:50%;transform:translate(-50%,-50%)}.devui-input-group .devui-form-control{cursor:pointer;display:block;width:100%;min-height:28px;height:unset;padding:4px 8px;font-size:var(--devui-font-size, 12px);line-height:1.5;background-image:none;border:1px solid var(--devui-form-control-line, #d7d8da);border-radius:var(--devui-border-radius, 2px) 0 0 var(--devui-border-radius, 2px);transition:border-color var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1)),box-shadow var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1))}.devui-input-group .devui-form-control.devui-files-list{max-height:52px;padding:2px 2px 0;overflow-x:hidden;overflow-y:auto;max-width:100%}.devui-input-group .devui-form-control.devui-files-list .devui-file-item{height:22px;line-height:22px;padding:0 48px 0 12px}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag{position:relative;background-color:var(--devui-label-bg, #e9edfa);border-radius:var(--devui-border-radius, 2px);max-width:100%}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .devui-filename{height:100%;display:inline-block;vertical-align:middle;max-width:100%;overflow:hidden;white-space:nowrap;text-overflow:ellipsis}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon{position:absolute;cursor:pointer;right:8px;top:50%;transform:translateY(-50%);line-height:1}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon.icon-right{color:var(--devui-success, #3ac295)}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon.icon-running{font-size:16px}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon.devui-upload-delete-file-button{margin-right:20px}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon.devui-uploading-delete{display:none}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon.devui-upload-remove{width:16px;height:16px}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon.devui-upload-remove svg path{fill:var(--devui-text, #252b3a)}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag:hover .devui-upload-progress,.devui-input-group .devui-form-control.devui-files-list .devui-file-tag:hover .icon-right{display:none}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag:hover .devui-upload-remove{display:inline-block}.devui-input-group.disabled .devui-upload-placeholder{color:var(--devui-disabled-text, #babbc0)}.devui-input-group .devui-upload-placeholder{max-height:28px;max-width:100%;overflow:hidden;white-space:nowrap;text-overflow:ellipsis;color:var(--devui-placeholder, #babbc0)}:host ::ng-deep .devui-upload-progress{width:16px;height:16px}.devui-input-group.disabled .devui-form-control,.devui-input-group.disabled .devui-input-group-addon{cursor:not-allowed;background-color:var(--devui-disabled-bg, #f5f5f5);border-color:var(--devui-disabled-line, #dfe1e6);color:var(--devui-disabled-text, #babbc0)}svg.svg-icon-dot>path{fill:var(--devui-icon-text, #71757f)}.devui-form-control{outline:none}.devui-input-group.disabled .devui-upload-delete-file-button{cursor:not-allowed;pointer-events:none}.devui-loading{color:var(--devui-aide-text, #71757f)}.devui-failed-color{color:var(--devui-danger, #f66f6a)}.devui-upload-tip{height:18px;margin-top:8px;font-size:12px}.devui-upload-tip .icon{margin-right:8px;font-size:16px;vertical-align:middle}.devui-upload-tip .icon-right-o{color:var(--devui-success, #3ac295)}.devui-upload-tip .devui-upload-failed{color:var(--devui-danger, #f66f6a)}.devui-upload-tip a{color:var(--devui-link, #526ecc);cursor:pointer}.with-button{max-width:calc(100% - 72px)}\n"], dependencies: [{ kind: "directive", type: i6.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i6.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { kind: "component", type: i7.ButtonComponent, selector: "d-button", inputs: ["id", "type", "bsStyle", "shape", "bsSize", "bsPosition", "bordered", "icon", "disabled", "showLoading", "width", "autofocus", "loadingTemplateRef"], outputs: ["btnClick"] }, { kind: "component", type: i8.ProgressComponent, selector: "d-progress", inputs: ["isDynamic", "percentage", "percentageText", "barbgcolor", "strokeColor", "height", "strokeWidth", "isCircle", "type", "showContent", "multiProgressConfig"] }, { kind: "component", type: SingleUploadViewComponent, selector: "d-single-upload-view", inputs: ["uploadOptions", "preloadFilesRef", "uploadedFiles", "uploadedFilesRef", "filePath", "dynamicUploadOptionsFn"], outputs: ["deleteUploadedFileEvent"], exportAs: ["dSingleUploadView"] }, { kind: "directive", type: FileDropDirective, selector: "[d-file-drop]", inputs: ["enableDrop", "isSingle"], outputs: ["fileOver", "fileDrop"] }] }); }
}
__decorate([
    WithConfig(),
    __metadata("design:type", Object)
], SingleUploadComponent.prototype, "showGlowStyle", void 0);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: SingleUploadComponent, decorators: [{
            type: Component,
            args: [{ selector: 'd-single-upload', exportAs: 'dSingleUpload', providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => SingleUploadComponent),
                            multi: true,
                        },
                    ], preserveWhitespaces: false, template: "<div\r\n  d-file-drop\r\n  [enableDrop]=\"enableDrop\"\r\n  [isSingle]=\"true\"\r\n  (fileDrop)=\"onFileDrop($event)\"\r\n  (fileOver)=\"onFileOver($event)\"\r\n  (fileSelect)=\"onFileSelect($event)\"\r\n  [ngStyle]=\"{ border: isDropOVer ? '1px solid #15bf15' : '0' }\"\r\n  style=\"display: flex\"\r\n>\r\n  <div\r\n    class=\"devui-input-group\"\r\n    [class.disabled]=\"this.disabled || dSingleUploadView.fileUploaders[0]?.status === UploadStatus.uploading\"\r\n    [class.with-button]=\"!withoutBtn\"\r\n    (click)=\"onClick($event)\"\r\n  >\r\n    <div class=\"devui-form-control devui-files-list\">\r\n      <div *ngIf=\"!filename\" class=\"devui-file-item devui-upload-placeholder\">\r\n        {{ placeholderText ? placeholderText : i18nText?.chooseFile }}\r\n      </div>\r\n      <div *ngIf=\"!!filename\" class=\"devui-file-tag devui-file-item\" title=\"{{ filename }}\">\r\n        <span class=\"devui-filename {{ dSingleUploadView.fileUploaders[0]?.status === UploadStatus.failed ? 'devui-failed-color' : '' }}\">\r\n          {{ filename }}\r\n        </span>\r\n        <span\r\n          class=\"icon devui-upload-remove\r\n            {{ dSingleUploadView.fileUploaders[0]?.status === UploadStatus.failed ? 'devui-upload-delete-file-button' : '' }}\r\n            {{\r\n            dSingleUploadView.fileUploaders[0]?.status === UploadStatus.uploading ||\r\n            dSingleUploadView.fileUploaders[0]?.status === UploadStatus.uploaded\r\n              ? 'devui-uploading-delete'\r\n              : ''\r\n          }}\"\r\n          (click)=\"deleteFile($event)\"\r\n        >\r\n          <svg\r\n            width=\"16px\"\r\n            height=\"16px\"\r\n            viewBox=\"0 0 16 16\"\r\n            version=\"1.1\"\r\n            xmlns=\"http://www.w3.org/2000/svg\"\r\n            xmlns:xlink=\"http://www.w3.org/1999/xlink\"\r\n          >\r\n            <g stroke=\"none\" stroke-width=\"1\" fill=\"none\" fill-rule=\"evenodd\">\r\n              <g transform=\"translate(-270.000000, -2376.000000)\">\r\n                <g transform=\"translate(198.000000, 1991.000000)\">\r\n                  <g transform=\"translate(0.000000, 383.000000)\">\r\n                    <g transform=\"translate(72.000000, 2.000000)\">\r\n                      <path\r\n                        d=\"M4.570404,4.06442993 L4.6207661,4.10650663 L8,7.48581818 L11.3792339,4.10650663 C11.5212427,3.96449779 11.7514845,3.96449779 11.8934934,4.10650663 C12.0197234,4.2327367 12.033749,4.42868172 11.9355701,4.570404 L11.8934934,4.6207661 L8.51418182,8 L11.8934934,11.3792339 C12.0355022,11.5212427 12.0355022,11.7514845 11.8934934,11.8934934 C11.7672633,12.0197234 11.5713183,12.033749 11.429596,11.9355701 L11.3792339,11.8934934 L8,8.51418182 L4.6207661,11.8934934 C4.47875727,12.0355022 4.24851546,12.0355022 4.10650663,11.8934934 C3.98027655,11.7672633 3.96625099,11.5713183 4.06442993,11.429596 L4.10650663,11.3792339 L7.48581818,8 L4.10650663,4.6207661 C3.96449779,4.47875727 3.96449779,4.24851546 4.10650663,4.10650663 C4.2327367,3.98027655 4.42868172,3.96625099 4.570404,4.06442993 Z\"\r\n                      ></path>\r\n                    </g>\r\n                  </g>\r\n                </g>\r\n              </g>\r\n            </g>\r\n          </svg>\r\n        </span>\r\n        <div *ngIf=\"dSingleUploadView.fileUploaders[0]?.status === UploadStatus.uploading\" class=\"icon devui-upload-progress\">\r\n          <d-progress\r\n            [type]=\"'circle'\"\r\n            [percentage]=\"dSingleUploadView.fileUploaders[0].percentage\"\r\n            [strokeColor]=\"'#50D4AB'\"\r\n            [strokeWidth]=\"8\"\r\n            [showContent]=\"false\"\r\n          >\r\n          </d-progress>\r\n        </div>\r\n        <span *ngIf=\"dSingleUploadView.fileUploaders[0]?.status === UploadStatus.failed\" class=\"icon icon-running\" (click)=\"upload()\">\r\n        </span>\r\n        <span *ngIf=\"dSingleUploadView.fileUploaders[0]?.status === UploadStatus.uploaded\" class=\"icon icon-right\"></span>\r\n      </div>\r\n    </div>\r\n    <span class=\"devui-input-group-addon\">\r\n      <svg class=\"svg-icon-dot\" height=\"1em\" width=\"1em\" viewBox=\"0 0 1024 1024\" xmlns=\"http://www.w3.org/2000/svg\">\r\n        <path\r\n          d=\"m400.31892 176.970574c0-61.574381 50.113351-111.680569 111.679545-111.680569 61.576427 0 111.680569 50.106188 111.680569 111.680569 0 61.568241-50.104141 111.679545-111.680569 111.679545-61.566194 0-111.679545-50.111304-111.679545-111.679545zm0 335.028403c0-61.568241 50.113351-111.678522 111.679545-111.678522 61.576427 0 111.680569 50.110281 111.680569 111.678522 0 61.574381-50.105165 111.682615-111.680569 111.682615-61.566194 0-111.679545-50.108235-111.679545-111.682615zm0 335.037612c0-61.572334 50.113351-111.679545 111.679545-111.679545 61.575404 0 111.680569 50.107211 111.680569 111.679545 0 61.567217-50.105165 111.672382-111.680569 111.672382-61.566194 0-111.679545-50.105164-111.679545-111.672382zm0 0\"\r\n        />\r\n      </svg>\r\n    </span>\r\n  </div>\r\n  <d-button\r\n    *ngIf=\"!autoUpload && !withoutBtn\"\r\n    (btnClick)=\"upload()\"\r\n    bsStyle=\"common\"\r\n    [style.margin-left.px]=\"8\"\r\n    [disabled]=\"\r\n      disabled ||\r\n      dSingleUploadView.uploadedFilesComponent.uploadedFiles.length > 0 ||\r\n      dSingleUploadView.fileUploaders[0]?.status === UploadStatus.uploading\r\n    \"\r\n  >\r\n    <span *ngIf=\"!dSingleUploadView.fileUploaders[0] || dSingleUploadView.fileUploaders[0]?.status === UploadStatus.preLoad\">{{\r\n      uploadText || i18nText?.upload\r\n    }}</span>\r\n    <span *ngIf=\"dSingleUploadView.fileUploaders[0]?.status === UploadStatus.uploading\">{{ i18nText?.uploading }}</span>\r\n    <span *ngIf=\"dSingleUploadView.fileUploaders[0]?.status === UploadStatus.uploaded\">{{ i18nText?.uploaded }}</span>\r\n    <span *ngIf=\"dSingleUploadView.fileUploaders[0]?.status === UploadStatus.failed\">{{ i18nText?.uploadFailed }}</span>\r\n  </d-button>\r\n</div>\r\n<ng-container *ngIf=\"showTip\">\r\n  <div class=\"devui-upload-tip\">\r\n    <span *ngIf=\"dSingleUploadView.fileUploaders[0]?.status === UploadStatus.uploading\" class=\"devui-loading\">\r\n      {{ i18nText?.uploading }}\r\n    </span>\r\n    <div *ngIf=\"dSingleUploadView.fileUploaders[0]?.status === UploadStatus.uploaded\" class=\"devui-loaded\">\r\n      <i class=\"icon icon-right-o\"></i>\r\n      <span style=\"vertical-align: middle\">{{ i18nText?.uploadSuccess }}</span>\r\n    </div>\r\n    <div *ngIf=\"dSingleUploadView.fileUploaders[0]?.status === UploadStatus.failed\" class=\"devui-upload-failed\">\r\n      <i class=\"icon icon-info-o\"></i>\r\n      <span style=\"vertical-align: middle\">\r\n        <span style=\"margin-right: 8px\">{{ i18nText?.uploadFailed }}</span>\r\n        <a (click)=\"upload()\">{{ i18nText?.reUpload }}</a>\r\n      </span>\r\n    </div>\r\n  </div>\r\n</ng-container>\r\n<d-single-upload-view\r\n  #dSingleUploadView=\"dSingleUploadView\"\r\n  [uploadOptions]=\"uploadOptions\"\r\n  [filePath]=\"filePath\"\r\n  [uploadedFiles]=\"uploadedFiles\"\r\n  [uploadedFilesRef]=\"uploadedFilesRef\"\r\n  [preloadFilesRef]=\"preloadFilesRef\"\r\n  [dynamicUploadOptionsFn]=\"dynamicUploadOptionsFn\"\r\n  (deleteUploadedFileEvent)=\"_onDeleteUploadedFile($event)\"\r\n>\r\n</d-single-upload-view>\r\n", styles: [".devui-font-size-base{font-size:var(--devui-font-size, 12px)}.devui-font-base{font-size:var(--devui-font-size, 12px);font-weight:var(--devui-font-content-weight, normal);line-height:var(--devui-line-height-base, 1.5)}.devui-font-size-modal-title{font-size:var(--devui-font-size-modal-title, 18px)}.devui-font-modal-title{font-size:var(--devui-font-size-modal-title, 18px);font-weight:var(--devui-font-title-weight, bold);line-height:var(--devui-line-height-base, 1.5)}.devui-font-size-page-title{font-size:var(--devui-font-size-page-title, 16px)}.devui-font-page-title{font-size:var(--devui-font-size-page-title, 16px);font-weight:var(--devui-font-title-weight, bold);line-height:var(--devui-line-height-base, 1.5)}.devui-font-size-secondary-title{font-size:var(--devui-font-size-card-title, 14px)}.devui-font-secondary-title{font-size:var(--devui-font-size-card-title, 14px);font-weight:var(--devui-font-title-weight, bold);line-height:var(--devui-line-height-base, 1.5)}.devui-input-group{position:relative;display:flex;align-items:center;border-collapse:separate;width:100%;border-radius:var(--devui-border-radius, 2px)}.devui-input-group:not(.disabled):hover .devui-input-group-addon{background-color:var(--devui-dividing-line, #eef0f5);font-weight:700}.devui-input-group:not(.disabled):hover .devui-form-control{border-right-color:var(--devui-form-control-line, #d7d8da)}.devui-input-group:not(.disabled) .devui-input-group-addon:active{border-color:var(--devui-form-control-line-active, #5e7ce0);border-right-color:var(--devui-form-control-line, #d7d8da);background-color:var(--devui-dividing-line, #eef0f5)}.devui-input-group .devui-input-group-addon{width:36px;white-space:nowrap;font-size:var(--devui-font-size-icon, 16px);font-weight:400;line-height:1;color:var(--devui-text, #252b3a);background-color:var(--devui-area, #f5f5f5);border-top:1px solid var(--devui-form-control-line, #d7d8da);border-bottom:1px solid var(--devui-form-control-line, #d7d8da);border-right:1px solid var(--devui-form-control-line, #d7d8da);border-radius:0 var(--devui-border-radius, 2px) var(--devui-border-radius, 2px) 0;transition:border-color var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1)),background-color var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1));cursor:pointer;height:100%;position:relative;display:inline-block}.devui-input-group .devui-input-group-addon svg{position:absolute;left:50%;top:50%;transform:translate(-50%,-50%)}.devui-input-group .devui-form-control{cursor:pointer;display:block;width:100%;min-height:28px;height:unset;padding:4px 8px;font-size:var(--devui-font-size, 12px);line-height:1.5;background-image:none;border:1px solid var(--devui-form-control-line, #d7d8da);border-radius:var(--devui-border-radius, 2px) 0 0 var(--devui-border-radius, 2px);transition:border-color var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1)),box-shadow var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1))}.devui-input-group .devui-form-control.devui-files-list{max-height:52px;padding:2px 2px 0;overflow-x:hidden;overflow-y:auto;max-width:100%}.devui-input-group .devui-form-control.devui-files-list .devui-file-item{height:22px;line-height:22px;padding:0 48px 0 12px}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag{position:relative;background-color:var(--devui-label-bg, #e9edfa);border-radius:var(--devui-border-radius, 2px);max-width:100%}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .devui-filename{height:100%;display:inline-block;vertical-align:middle;max-width:100%;overflow:hidden;white-space:nowrap;text-overflow:ellipsis}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon{position:absolute;cursor:pointer;right:8px;top:50%;transform:translateY(-50%);line-height:1}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon.icon-right{color:var(--devui-success, #3ac295)}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon.icon-running{font-size:16px}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon.devui-upload-delete-file-button{margin-right:20px}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon.devui-uploading-delete{display:none}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon.devui-upload-remove{width:16px;height:16px}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag .icon.devui-upload-remove svg path{fill:var(--devui-text, #252b3a)}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag:hover .devui-upload-progress,.devui-input-group .devui-form-control.devui-files-list .devui-file-tag:hover .icon-right{display:none}.devui-input-group .devui-form-control.devui-files-list .devui-file-tag:hover .devui-upload-remove{display:inline-block}.devui-input-group.disabled .devui-upload-placeholder{color:var(--devui-disabled-text, #babbc0)}.devui-input-group .devui-upload-placeholder{max-height:28px;max-width:100%;overflow:hidden;white-space:nowrap;text-overflow:ellipsis;color:var(--devui-placeholder, #babbc0)}:host ::ng-deep .devui-upload-progress{width:16px;height:16px}.devui-input-group.disabled .devui-form-control,.devui-input-group.disabled .devui-input-group-addon{cursor:not-allowed;background-color:var(--devui-disabled-bg, #f5f5f5);border-color:var(--devui-disabled-line, #dfe1e6);color:var(--devui-disabled-text, #babbc0)}svg.svg-icon-dot>path{fill:var(--devui-icon-text, #71757f)}.devui-form-control{outline:none}.devui-input-group.disabled .devui-upload-delete-file-button{cursor:not-allowed;pointer-events:none}.devui-loading{color:var(--devui-aide-text, #71757f)}.devui-failed-color{color:var(--devui-danger, #f66f6a)}.devui-upload-tip{height:18px;margin-top:8px;font-size:12px}.devui-upload-tip .icon{margin-right:8px;font-size:16px;vertical-align:middle}.devui-upload-tip .icon-right-o{color:var(--devui-success, #3ac295)}.devui-upload-tip .devui-upload-failed{color:var(--devui-danger, #f66f6a)}.devui-upload-tip a{color:var(--devui-link, #526ecc);cursor:pointer}.with-button{max-width:calc(100% - 72px)}\n"] }]
        }], ctorParameters: () => [{ type: i1.I18nService }, { type: SelectFiles }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }, { type: i5.ToastService }, { type: SliceUploadService }, { type: i4.DevConfigService }], propDecorators: { uploadOptions: [{
                type: Input
            }], fileOptions: [{
                type: Input
            }], autoUpload: [{
                type: Input
            }], withoutBtn: [{
                type: Input
            }], showTip: [{
                type: Input
            }], uploadedFiles: [{
                type: Input
            }], uploadedFilesRef: [{
                type: Input
            }], preloadFilesRef: [{
                type: Input
            }], filePath: [{
                type: Input
            }], placeholderText: [{
                type: Input
            }], uploadText: [{
                type: Input
            }], confirmText: [{
                type: Input
            }], beforeUpload: [{
                type: Input
            }], dynamicUploadOptionsFn: [{
                type: Input
            }], enableDrop: [{
                type: Input
            }], disabled: [{
                type: Input
            }], successEvent: [{
                type: Output
            }], errorEvent: [{
                type: Output
            }], errorChunkEvent: [{
                type: Output
            }], deleteUploadedFileEvent: [{
                type: Output
            }], fileDrop: [{
                type: Output
            }], fileOver: [{
                type: Output
            }], fileSelect: [{
                type: Output
            }], showGlowStyle: [{
                type: Input
            }], hasGlowStyle: [{
                type: HostBinding,
                args: ['class.devui-glow-style']
            }], singleUploadViewComponent: [{
                type: ViewChild,
                args: ['dSingleUploadView', { static: true }]
            }] } });

class UploadDirective extends UploadComponent {
    constructor(selectFiles, i18n, element) {
        super();
        this.selectFiles = selectFiles;
        this.i18n = i18n;
        this.uploadedFiles = [];
        this.fileUploaders = [];
        this.enableDrop = false;
        this.fileOver = new EventEmitter();
        this.fileDrop = new EventEmitter();
        this.successEvent = new EventEmitter();
        this.errorEvent = new EventEmitter();
        this.alertMsgEvent = new EventEmitter();
        this.fileSelect = new EventEmitter();
        this.errorMsg = [];
        this.onChange = (_) => null;
        this.onTouched = () => null;
        this.element = element;
        this.i18nText = this.i18n.getI18nText().upload;
        this.i18nSubscription = this.i18n.langChange().subscribe((data) => {
            this.i18nText = data.upload;
        });
    }
    writeValue(files) {
        if (files) {
            const simulateFiles = from(this.simulateSelectFiles(files)).pipe(mergeMap(file => file));
            this._dealFiles(simulateFiles);
        }
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    simulateSelectFiles(files) {
        return new Promise((resolve) => {
            resolve(Array.prototype.slice.call(files));
        });
    }
    onClick() {
        this._dealFiles(this.selectFiles.triggerSelectFiles(this.fileOptions, this.uploadOptions));
    }
    _dealFiles(observale) {
        super.resetSameNameFiles();
        observale.pipe(map(file => {
            let uploadOptions = this.uploadOptions;
            if (this.dynamicUploadOptionsFn) {
                uploadOptions = this.dynamicUploadOptionsFn(file, this.uploadOptions);
            }
            super.addFile(file, uploadOptions);
        }), debounceTime(100))
            .subscribe(() => {
            this.checkValid();
            this.checkSameName();
            const selectedFiles = this.fileUploaders
                .filter(fileUploader => fileUploader.status === UploadStatus.preLoad)
                .map(fileUploader => fileUploader.file);
            this.onFileSelect(selectedFiles);
            this.uploadFiles();
        }, (error) => {
            this.errorMsg = [{ severity: 'warn', detail: error.message }];
            this.alertMsgEvent.emit(this.errorMsg);
        });
    }
    checkSameName() {
        const sameNameFiles = super.getSameNameFiles();
        if (this.uploadOptions.checkSameName && sameNameFiles.length) {
            this.errorMsg = [{
                    severity: 'warn',
                    detail: this.i18nText.getExistSameNameFilesMsg(sameNameFiles)
                }];
            this.alertMsgEvent.emit(this.errorMsg);
        }
    }
    // 文件大小、类型是否符合上传条件
    checkValid() {
        let totalFileSize = 0;
        this.fileUploaders.forEach(fileUploader => {
            totalFileSize += fileUploader.file.size;
            const checkResult = this.selectFiles._validateFiles(this.fileUploaders.length, fileUploader.file, this.fileOptions.accept, fileUploader.uploadOptions);
            if (checkResult && checkResult.checkError) {
                super.deleteFile(fileUploader.file);
                this.errorMsg = [{ severity: 'warn', detail: checkResult.errorMsg }];
                this.alertMsgEvent.emit(this.errorMsg);
                return;
            }
        });
    }
    uploadFiles() {
        this.canUpload().then((canUpload) => {
            if (!canUpload) {
                return;
            }
            const uploadObservable = super.upload();
            uploadObservable
                .pipe(last())
                .subscribe((results) => {
                this.successEvent.emit(results);
                results.forEach((result) => {
                    this.uploadedFiles.push(result.file);
                });
            }, (error) => {
                this.errorEvent.emit(error);
            });
        });
    }
    onFileSelect(files) {
        this.fileSelect.emit(files);
    }
    onDrop(event) {
        if (!this.enableDrop) {
            return;
        }
        const transfer = this._getTransfer(event);
        if (!transfer) {
            return;
        }
        this._preventAndStop(event);
        this._dealFiles(this.selectFiles.triggerDropFiles(this.fileOptions, this.uploadOptions, transfer.files));
        this.fileDrop.emit(transfer.files);
    }
    onDragOver(event) {
        if (!this.enableDrop) {
            return;
        }
        const transfer = this._getTransfer(event);
        if (!this._haveFiles(transfer.types)) {
            return;
        }
        this._preventAndStop(event);
        this.fileOver.emit(true);
    }
    onDragLeave(event) {
        if (!this.enableDrop) {
            return;
        }
        if (this.element) {
            if (event.currentTarget === this.element[0]) {
                return;
            }
        }
        this._preventAndStop(event);
        this.fileOver.emit(false);
    }
    _getTransfer(event) {
        return event.dataTransfer ? event.dataTransfer : event.originalEvent.dataTransfer;
    }
    _preventAndStop(event) {
        event.preventDefault();
        event.stopPropagation();
    }
    _haveFiles(types) {
        if (!types) {
            return false;
        }
        if (types.indexOf) {
            return types.indexOf('Files') !== -1;
        }
        else if (types.contains) {
            return types.contains('Files');
        }
        else {
            return false;
        }
    }
    canUpload() {
        let uploadResult = Promise.resolve(true);
        if (this.beforeUpload) {
            const result = this.beforeUpload(this.fileUploaders);
            if (typeof result !== 'undefined') {
                if (result.then) {
                    uploadResult = result;
                }
                else if (result.subscribe) {
                    uploadResult = result.toPromise();
                }
                else {
                    uploadResult = Promise.resolve(result);
                }
            }
        }
        return uploadResult;
    }
    ngOnDestroy() {
        if (this.i18nSubscription) {
            this.i18nSubscription.unsubscribe();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: UploadDirective, deps: [{ token: SelectFiles }, { token: i1.I18nService }, { token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.2.3", type: UploadDirective, selector: "[dUpload]", inputs: { uploadOptions: "uploadOptions", fileOptions: "fileOptions", uploadedFiles: "uploadedFiles", fileUploaders: "fileUploaders", enableDrop: "enableDrop", dynamicUploadOptionsFn: "dynamicUploadOptionsFn", beforeUpload: "beforeUpload" }, outputs: { fileOver: "fileOver", fileDrop: "fileDrop", successEvent: "successEvent", errorEvent: "errorEvent", alertMsgEvent: "alertMsgEvent", fileSelect: "fileSelect" }, host: { listeners: { "click": "onClick()", "drop": "onDrop($event)", "dragover": "onDragOver($event)", "dragleave": "onDragLeave($event)" } }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => UploadDirective),
                multi: true
            }
        ], exportAs: ["dUpload"], usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: UploadDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[dUpload]',
                    exportAs: 'dUpload',
                    providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => UploadDirective),
                            multi: true
                        }
                    ],
                }]
        }], ctorParameters: () => [{ type: SelectFiles }, { type: i1.I18nService }, { type: i0.ElementRef }], propDecorators: { uploadOptions: [{
                type: Input
            }], fileOptions: [{
                type: Input
            }], uploadedFiles: [{
                type: Input
            }], fileUploaders: [{
                type: Input
            }], enableDrop: [{
                type: Input
            }], dynamicUploadOptionsFn: [{
                type: Input
            }], beforeUpload: [{
                type: Input
            }], fileOver: [{
                type: Output
            }], fileDrop: [{
                type: Output
            }], successEvent: [{
                type: Output
            }], errorEvent: [{
                type: Output
            }], alertMsgEvent: [{
                type: Output
            }], fileSelect: [{
                type: Output
            }], onClick: [{
                type: HostListener,
                args: ['click']
            }], onDrop: [{
                type: HostListener,
                args: ['drop', ['$event']]
            }], onDragOver: [{
                type: HostListener,
                args: ['dragover', ['$event']]
            }], onDragLeave: [{
                type: HostListener,
                args: ['dragleave', ['$event']]
            }] } });

class UploadModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: UploadModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.2.3", ngImport: i0, type: UploadModule, declarations: [MultipleUploadViewComponent,
            SingleUploadViewComponent,
            SingleUploadComponent,
            MultipleUploadComponent,
            UploadedFilesComponent,
            FileDropDirective,
            UploadDirective], imports: [CommonModule,
            ButtonModule,
            ToastModule,
            ProgressModule], exports: [MultipleUploadViewComponent,
            SingleUploadViewComponent,
            SingleUploadComponent,
            MultipleUploadComponent,
            UploadedFilesComponent,
            FileDropDirective,
            UploadDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: UploadModule, providers: [SelectFiles, SliceUploadService], imports: [CommonModule,
            ButtonModule,
            ToastModule,
            ProgressModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: UploadModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        ButtonModule,
                        ToastModule,
                        ProgressModule
                    ],
                    exports: [
                        MultipleUploadViewComponent,
                        SingleUploadViewComponent,
                        SingleUploadComponent,
                        MultipleUploadComponent,
                        UploadedFilesComponent,
                        FileDropDirective,
                        UploadDirective,
                    ],
                    declarations: [
                        MultipleUploadViewComponent,
                        SingleUploadViewComponent,
                        SingleUploadComponent,
                        MultipleUploadComponent,
                        UploadedFilesComponent,
                        FileDropDirective,
                        UploadDirective,
                    ],
                    providers: [SelectFiles, SliceUploadService],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { FileDropDirective, FileUploader, IFileOptions, IUploadOptions, MultipleUploadComponent, MultipleUploadViewComponent, SelectFiles, SingleUploadComponent, SingleUploadViewComponent, SliceUploadService, UploadComponent, UploadDirective, UploadModule, UploadStatus, UploadedFilesComponent };
//# sourceMappingURL=ng-devui-upload.mjs.map
